@@ -128,6 +128,14 @@ static float strtof(const char* cptr, char** endptr) {
 #  define _DEPRECATED_TYPEDEF(type, deprecated_type) typedef type deprecated_type _DEPRECATED
 #  define stdext __gnu_cxx
 
+// disable some specific C++11 warnings with clang
+#if __clang_major__ >= 3 && __clang_minor__ >= 4
+#pragma clang diagnostic ignored "-Wdeprecated-register"
+#endif
+#if __clang_major__ >= 3 && __clang_minor__ >= 5
+#pragma clang diagnostic ignored "-Wtautological-undefined-compare"
+#endif
+
 //for GCC 4.X
 #else
 #    define _DEPRECATED __attribute__ ((deprecated))
@@ -135,8 +143,10 @@ static float strtof(const char* cptr, char** endptr) {
 #    define stdext __gnu_cxx
 #  if  (__GNUC_MINOR__ < 4 && __GNUC__ < 4)
 #    include <ext/stl_hash_fun.h>
-#  elif (__GNUC_MINOR__ < 3)
+#  elif (__GNUC_MINOR__ < 3 && __GNUC__ <= 4)
 #    include <ext/hash_fun.h>
+#  elif (__GNUC_MINOR__ > 3 && __GNUC__ >= 4)
+#    include <backward/hash_fun.h>
 #  endif
 #endif
 
