@@ -42,6 +42,7 @@
 #include <tulip/BoundingBox.h>
 #include <tulip/DrawingTools.h>
 #include <tulip/TulipViewSettings.h>
+#include <tulip/TulipFontAwesome.h>
 
 using namespace std;
 using namespace tlp;
@@ -96,7 +97,7 @@ ostream & operator << (ostream &os,const Graph *sp) {
 
 static void setViewPropertiesDefaults(Graph *g) {
 
-  const std::string shapes = "viewShape", colors = "viewColor", sizes = "viewSize", metrics = "viewMetric", fonts = "viewFont", fontSizes = "viewFontSize",
+  const std::string shapes = "viewShape", colors = "viewColor", sizes = "viewSize", metrics = "viewMetric", fonts = "viewFont", fontAwesomeIcon = "viewFontAwesomeIcon", fontSizes = "viewFontSize",
                     borderWidth = "viewBorderWidth", borderColor = "viewBorderColor", tgtShape = "viewTgtAnchorShape", srcShape = "viewSrcAnchorShape",
                     labelColor = "viewLabelColor", labelBorderColor = "viewLabelBorderColor", labelBorderWidth = "viewLabelBorderWidth", labelPosition = "viewLabelPosition", label="viewLabel",
                     layout = "viewLayout", rotation = "viewRotation", srcAnchorSize = "viewSrcAnchorSize", selection = "viewSelection", texture = "viewTexture", tgtAnchorSize = "viewTgtAnchorSize";
@@ -202,6 +203,11 @@ static void setViewPropertiesDefaults(Graph *g) {
     g->getProperty<BooleanProperty>(selection)->setAllEdgeValue(false);
   }
 
+  if (!g->existProperty(fontAwesomeIcon)) {
+    g->getProperty<StringProperty>(fontAwesomeIcon)->setAllNodeValue(TulipFontAwesome::QuestionCircle);
+    g->getProperty<StringProperty>(fontAwesomeIcon)->setAllEdgeValue(TulipFontAwesome::QuestionCircle);
+  }
+
 }
 
 //=========================================================
@@ -267,6 +273,9 @@ Graph * tlp::importGraph(const std::string &format, DataSet &dataSet, PluginProg
   ImportModule *newImportModule = PluginLister::instance()->getPluginObject<ImportModule>(format, tmp);
   assert(newImportModule!=NULL);
 
+  // ensure that the parsing of float or double does not depend on locale
+  setlocale(LC_NUMERIC, "C");
+
   //If the import failed and we created the graph then delete the graph
   if (!newImportModule->importGraph()) {
     graph = NULL;
@@ -499,8 +508,9 @@ public:
 
     // we iterate the observable graph nodes
     node n;
-    Graph* g;
     forEach(n, ovg.getNodes()) {
+      Graph* g;
+
       if (tlp::Observable::isAlive(n) &&
           (g = dynamic_cast<Graph*>(tlp::Observable::getObject(n)))) {
         // check if g is a root graph
@@ -561,6 +571,7 @@ bool Graph::applyAlgorithm(const std::string &algorithm,
   }
 
   delete newAlgo;
+  delete context;
 
   if (deletePluginProgress)
     delete tmpProgress;
@@ -985,11 +996,9 @@ void updatePropertiesUngroup(Graph *graph, node metanode,
   SizeProperty  *clusterSize   = cluster->getProperty<SizeProperty>(sizeProperty);
   DoubleProperty *clusterRot = cluster->getProperty<DoubleProperty>(rotationProperty);
   BoundingBox box = tlp::computeBoundingBox(cluster, clusterLayout, clusterSize, clusterRot);
-  Coord maxL(box[1]);
-  Coord minL(box[0]);
-  double width  = maxL[0] - minL[0];
-  double height = maxL[1] - minL[1];
-  double depth =  maxL[2] - minL[2];
+  double width  = box.width();
+  double height = box.height();
+  double depth =  box.depth();
 
   if (width<0.0001) width=1.0;
 
@@ -997,12 +1006,23 @@ void updatePropertiesUngroup(Graph *graph, node metanode,
 
   if (depth<0.0001) depth=1.0;
 
-  Coord center = (maxL + minL) / -2.0f;
-  clusterLayout->translate(center, cluster);
+  // keep aspect ratio of content layout when opening a meta-node
+  double divW = size[0] / width;
+  double divH = size[1] / height;
+  double scale = 1.0;
+
+  if (divH * width > size[0]) {
+    scale = divW;
+  }
+  else {
+    scale = divH;
+  }
+
+  clusterLayout->translate(-box.center(), cluster);
   clusterLayout->rotateZ(graphRot->getNodeValue(metanode), cluster);
-  clusterLayout->scale(Coord(size[0]/width, size[1]/height, size[2]/depth), cluster);
+  clusterLayout->scale(Coord(scale, scale, size[2]/depth), cluster);
   clusterLayout->translate(pos, cluster);
-  clusterSize->scale(Size(size[0]/width, size[1]/height, size[2]/depth), cluster);
+  clusterSize->scale(Size(scale, scale, size[2]/depth), cluster);
 
   Iterator<node> *itN = cluster->getNodes();
 
@@ -1024,8 +1044,6 @@ void updatePropertiesUngroup(Graph *graph, node metanode,
 
   delete itE;
 
-
-
   // propagate all cluster local properties
   PropertyInterface* property;
   forEach(property, cluster->getLocalObjectProperties()) {
