@@ -70,12 +70,11 @@ TLPBImport::TLPBImport(tlp::PluginContext* context):ImportModule(context) {
 bool TLPBImport::importGraph() {
   std::string filename;
   std::istream* is = NULL;
-  bool result = false;
 
   if (dataSet->exist("file::filename")) {
     dataSet->get<std::string>("file::filename", filename);
     struct stat infoEntry;
-    result = (stat(filename.c_str(),&infoEntry) == 0);
+    bool result = (stat(filename.c_str(),&infoEntry) == 0);
 
     if (!result) {
       std::stringstream ess;
@@ -85,8 +84,12 @@ bool TLPBImport::importGraph() {
       return errorTrap();
     }
 
-    is = tlp::getInputFileStream(filename, std::ifstream::in |
-                                 std::ifstream::binary);
+    if (filename.rfind(".gz") == (filename.length() - 3)) {
+      is = tlp::getIgzstream(filename);
+    }
+    else
+      is = tlp::getInputFileStream(filename, std::ifstream::in |
+                                   std::ifstream::binary);
   }
   else {
     pluginProgress->setError("No file to open: 'file::filename' parameter is missing");
