@@ -499,11 +499,11 @@ struct TLPNodesBuilder:public TLPFalse {
 struct TLPEdgeBuilder:public TLPFalse {
   TLPGraphBuilder *graphBuilder;
   int nbParameter;
-  int parameter[3];
+  std::vector<int> parameters;
   TLPEdgeBuilder(TLPGraphBuilder *graphBuilder):graphBuilder(graphBuilder), nbParameter(0) {}
   bool addInt(const int id)  {
     if (nbParameter<3) {
-      parameter[nbParameter]=id;
+      parameters.push_back(id);
       nbParameter++;
       return true;
     }
@@ -512,7 +512,7 @@ struct TLPEdgeBuilder:public TLPFalse {
   }
   bool close()  {
     if (nbParameter==3) {
-      return graphBuilder->addEdge(parameter[0],parameter[1],parameter[2]);
+      return graphBuilder->addEdge(parameters[0],parameters[1],parameters[2]);
     }
     else
       return false;
@@ -731,18 +731,19 @@ struct TLPPropertyBuilder:public TLPFalse {
 
   virtual ~TLPPropertyBuilder() {}
   TLPPropertyBuilder(TLPGraphBuilder *graphBuilder):graphBuilder(graphBuilder), clusterId(INT_MAX), propertyType(std::string()), propertyName(std::string()), property(NULL), isGraphProperty(false), isPathViewProperty(false) {}
-  void getProperty() {
+  bool getProperty() {
     assert(property == NULL);
     property = graphBuilder->createProperty(clusterId, propertyType,
                                             propertyName, isGraphProperty,
                                             isPathViewProperty);
+    return property != NULL;
   }
   bool addInt(const int id)  {
     assert(id != INT_MAX);
     clusterId = id;
 
     if (!propertyType.empty() && !propertyName.empty())
-      getProperty();
+      return getProperty();
 
     return true;
   }
@@ -754,7 +755,7 @@ struct TLPPropertyBuilder:public TLPFalse {
       propertyName=str;
 
       if (clusterId != INT_MAX)
-        getProperty();
+        return getProperty();
     }
     else
       return false;
