@@ -3,7 +3,7 @@
  * This file is part of Tulip (www.tulip-software.org)
  *
  * Authors: David Auber and the Tulip development Team
- * from LaBRI, University of Bordeaux 1 and Inria Bordeaux - Sud Ouest
+ * from LaBRI, University of Bordeaux
  *
  * Tulip is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License
@@ -209,7 +209,7 @@ public slots:
     @brief defines the list of interactors available on this View
     @note Calling this will trigger the View::interactorsInstalled() callback for custom handling.
   */
-  void setInteractors(const QList<tlp::Interactor*>&);
+  virtual void setInteractors(const QList<tlp::Interactor*>&);
 
   /**
     @brief defines the active interactor that will receive user inputs.
