@@ -243,12 +243,12 @@ void GraphModel::treatEvent(const Event& ev) {
   MACRO(ColorVectorProperty,std::vector<tlp::Color>);\
   MACRO(SizeProperty,tlp::Size);\
   MACRO(SizeVectorProperty,std::vector<tlp::Size>);\
-  MACRO(StringProperty,std::string);\
+  /*MACRO(StringProperty,std::string);*/    \
   MACRO(StringVectorProperty,std::vector<std::string>);\
   MACRO(LayoutProperty,tlp::Coord);\
   MACRO(CoordVectorProperty,std::vector<tlp::Coord>);\
   MACRO(GraphProperty,tlp::Graph*);\
-  MACRO(IntegerProperty,int);\
+  /*MACRO(IntegerProperty,int);*/     \
   MACRO(IntegerVectorProperty,std::vector<int>);\
   MACRO(BooleanProperty,bool);
 
@@ -260,11 +260,11 @@ void GraphModel::treatEvent(const Event& ev) {
   MACRO(ColorVectorProperty,std::vector<tlp::Color>);\
   MACRO(SizeProperty,tlp::Size);\
   MACRO(SizeVectorProperty,std::vector<tlp::Size>);\
-  MACRO(StringProperty,std::string);\
+  /*MACRO(StringProperty,std::string);*/    \
   MACRO(StringVectorProperty,std::vector<std::string>);\
   MACRO(LayoutProperty,std::vector<tlp::Coord>);\
   MACRO(CoordVectorProperty,std::vector<tlp::Coord>);\
-  MACRO(IntegerProperty,int);\
+  /*MACRO(IntegerProperty,int);*/        \
   MACRO(IntegerVectorProperty,std::vector<int>);\
   MACRO(BooleanProperty,bool);
 
@@ -273,19 +273,27 @@ void GraphModel::treatEvent(const Event& ev) {
 QVariant GraphModel::nodeValue(unsigned int id, PropertyInterface * prop) {
   node n(id);
 
-  if (dynamic_cast<IntegerProperty*>(prop) != NULL && prop->getName() == "viewShape")
-    return QVariant::fromValue<NodeShape::NodeShapes>(static_cast<NodeShape::NodeShapes>(static_cast<IntegerProperty*>(prop)->getNodeValue(n)));
+  if (dynamic_cast<IntegerProperty*>(prop) != NULL) {
+    if (prop->getName() == "viewShape")
+      return QVariant::fromValue<NodeShape::NodeShapes>(static_cast<NodeShape::NodeShapes>(static_cast<IntegerProperty*>(prop)->getNodeValue(n)));
+
+    if (prop->getName() == "viewLabelPosition")
+      return QVariant::fromValue<LabelPosition::LabelPositions>(static_cast<LabelPosition::LabelPositions>(static_cast<IntegerProperty*>(prop)->getNodeValue(n)));
+
+    return QVariant::fromValue<int>(static_cast<IntegerProperty*>(prop)->getNodeValue(n));
+  }
   else if (dynamic_cast<StringProperty*>(prop) != NULL) {
     if (prop->getName() == "viewFont")
       return QVariant::fromValue<TulipFont>(TulipFont::fromFile(QString::fromUtf8(static_cast<StringProperty*>(prop)->getNodeValue(n).c_str())));
 
+    if (prop->getName() == "viewFontAwesomeIcon")
+      return QVariant::fromValue<TulipFontAwesomeIcon>(TulipFontAwesomeIcon(QString::fromUtf8(static_cast<StringProperty*>(prop)->getNodeValue(n).c_str())));
+
     if (prop->getName() == "viewTexture")
       return QVariant::fromValue<TulipFileDescriptor>(TulipFileDescriptor(QString::fromUtf8(static_cast<StringProperty*>(prop)->getNodeValue(n).c_str()),TulipFileDescriptor::File));
 
     return QVariant::fromValue<QString>(QString::fromUtf8(static_cast<StringProperty*>(prop)->getNodeValue(n).c_str()));
   }
-  else if (dynamic_cast<IntegerProperty*>(prop) != NULL && prop->getName() == "viewLabelPosition")
-    return QVariant::fromValue<LabelPosition::LabelPositions>(static_cast<LabelPosition::LabelPositions>(static_cast<IntegerProperty*>(prop)->getNodeValue(n)));
   else if (dynamic_cast<BooleanVectorProperty*>(prop) != NULL)
     return QVariant::fromValue<QVector<bool> >(QVector<bool>::fromStdVector(static_cast<BooleanVectorProperty*>(prop)->getNodeValue(n)));
 
@@ -295,19 +303,27 @@ QVariant GraphModel::nodeValue(unsigned int id, PropertyInterface * prop) {
 
 #define GET_NODE_DEFAULT_VALUE(PROP,TYPE) else if (dynamic_cast<PROP*>(prop) != NULL) return QVariant::fromValue< TYPE >(static_cast<PROP*>(prop)->getNodeDefaultValue())
 QVariant GraphModel::nodeDefaultValue(PropertyInterface * prop) {
-  if (dynamic_cast<IntegerProperty*>(prop) != NULL && prop->getName() == "viewShape")
-    return QVariant::fromValue<NodeShape::NodeShapes>(static_cast<NodeShape::NodeShapes>(static_cast<IntegerProperty*>(prop)->getNodeDefaultValue()));
+  if (dynamic_cast<IntegerProperty*>(prop) != NULL) {
+    if (prop->getName() == "viewShape")
+      return QVariant::fromValue<NodeShape::NodeShapes>(static_cast<NodeShape::NodeShapes>(static_cast<IntegerProperty*>(prop)->getNodeDefaultValue()));
+
+    if (prop->getName() == "viewLabelPosition")
+      return QVariant::fromValue<LabelPosition::LabelPositions>(static_cast<LabelPosition::LabelPositions>(static_cast<IntegerProperty*>(prop)->getNodeDefaultValue()));
+
+    return QVariant::fromValue<int>(static_cast<IntegerProperty*>(prop)->getNodeDefaultValue());
+  }
   else if (dynamic_cast<StringProperty*>(prop) != NULL) {
     if (prop->getName() == "viewFont")
       return QVariant::fromValue<TulipFont>(TulipFont::fromFile(QString::fromUtf8(static_cast<StringProperty*>(prop)->getNodeDefaultValue().c_str())));
 
+    if (prop->getName() == "viewFontAwesomeIcon")
+      return QVariant::fromValue<TulipFontAwesomeIcon>(TulipFontAwesomeIcon(QString::fromUtf8(static_cast<StringProperty*>(prop)->getNodeDefaultValue().c_str())));
+
     if (prop->getName() == "viewTexture")
       return QVariant::fromValue<TulipFileDescriptor>(TulipFileDescriptor(QString::fromUtf8(static_cast<StringProperty*>(prop)->getNodeDefaultValue().c_str()),TulipFileDescriptor::File));
 
     return QVariant::fromValue<QString>(QString::fromUtf8(static_cast<StringProperty*>(prop)->getNodeDefaultValue().c_str()));
   }
-  else if (dynamic_cast<IntegerProperty*>(prop) != NULL && prop->getName() == "viewLabelPosition")
-    return QVariant::fromValue<LabelPosition::LabelPositions>(static_cast<LabelPosition::LabelPositions>(static_cast<IntegerProperty*>(prop)->getNodeDefaultValue()));
   else if (dynamic_cast<BooleanVectorProperty*>(prop) != NULL)
     return QVariant::fromValue<QVector<bool> >(QVector<bool>::fromStdVector(static_cast<BooleanVectorProperty*>(prop)->getNodeDefaultValue()));
 
@@ -317,18 +333,24 @@ QVariant GraphModel::nodeDefaultValue(PropertyInterface * prop) {
 
 #define SET_ALL_NODE_VALUE(PROP,TYPE) else if (dynamic_cast<PROP*>(prop) != NULL) static_cast<PROP*>(prop)->setAllNodeValue(v.value< TYPE >())
 bool GraphModel::setAllNodeValue(PropertyInterface * prop, QVariant v) {
-  if (dynamic_cast<IntegerProperty*>(prop) != NULL && prop->getName() == "viewShape")
-    static_cast<IntegerProperty*>(prop)->setAllNodeValue(v.value<NodeShape::NodeShapes>());
+  if (dynamic_cast<IntegerProperty*>(prop) != NULL) {
+    if (prop->getName() == "viewShape")
+      static_cast<IntegerProperty*>(prop)->setAllNodeValue(v.value<NodeShape::NodeShapes>());
+    else if (prop->getName() == "viewLabelPosition")
+      static_cast<IntegerProperty*>(prop)->setAllNodeValue(v.value<LabelPosition::LabelPositions>());
+    else
+      static_cast<IntegerProperty*>(prop)->setAllNodeValue(v.value<int>());
+  }
   else if (dynamic_cast<StringProperty*>(prop) != NULL) {
     if (prop->getName() == "viewFont")
       static_cast<StringProperty*>(prop)->setAllNodeValue(std::string(v.value<TulipFont>().fontFile().toUtf8().data()));
+    else if (prop->getName() == "viewFontAwesomeIcon")
+      static_cast<StringProperty*>(prop)->setAllNodeValue(std::string(v.value<TulipFontAwesomeIcon>().iconName.toUtf8().data()));
     else if (prop->getName() == "viewTexture")
       static_cast<StringProperty*>(prop)->setAllNodeValue(std::string(v.value<TulipFileDescriptor>().absolutePath.toUtf8().data()));
     else
       static_cast<StringProperty*>(prop)->setAllNodeValue(std::string(v.value<QString>().toUtf8().data()));
   }
-  else if (dynamic_cast<IntegerProperty*>(prop) != NULL && prop->getName() == "viewLabelPosition")
-    static_cast<IntegerProperty*>(prop)->setAllNodeValue(v.value<LabelPosition::LabelPositions>());
   else if (dynamic_cast<BooleanVectorProperty*>(prop) != NULL)
     static_cast<BooleanVectorProperty*>(prop)->setAllNodeValue(v.value<QVector<bool> >().toStdVector());
 
@@ -343,18 +365,24 @@ bool GraphModel::setAllNodeValue(PropertyInterface * prop, QVariant v) {
 bool GraphModel::setNodeValue(unsigned int id, PropertyInterface * prop, QVariant v) {
   node n(id);
 
-  if (dynamic_cast<IntegerProperty*>(prop) != NULL && prop->getName() == "viewShape")
-    static_cast<IntegerProperty*>(prop)->setNodeValue(n,v.value<NodeShape::NodeShapes>());
+  if (dynamic_cast<IntegerProperty*>(prop) != NULL) {
+    if (prop->getName() == "viewShape")
+      static_cast<IntegerProperty*>(prop)->setNodeValue(n,v.value<NodeShape::NodeShapes>());
+    else if (prop->getName() == "viewLabelPosition")
+      static_cast<IntegerProperty*>(prop)->setNodeValue(n,v.value<LabelPosition::LabelPositions>());
+    else
+      static_cast<IntegerProperty*>(prop)->setNodeValue(n,v.value<int>());
+  }
   else if (dynamic_cast<StringProperty*>(prop) != NULL) {
     if (prop->getName() == "viewFont")
       static_cast<StringProperty*>(prop)->setNodeValue(n, std::string(v.value<TulipFont>().fontFile().toUtf8().data()));
+    else if (prop->getName() == "viewFontAwesomeIcon")
+      static_cast<StringProperty*>(prop)->setNodeValue(n,std::string(v.value<TulipFontAwesomeIcon>().iconName.toUtf8().data()));
     else if (prop->getName() == "viewTexture")
       static_cast<StringProperty*>(prop)->setNodeValue(n,std::string(v.value<TulipFileDescriptor>().absolutePath.toUtf8().data()));
     else
       static_cast<StringProperty*>(prop)->setNodeValue(n,std::string(v.value<QString>().toUtf8().data()));
   }
-  else if (dynamic_cast<IntegerProperty*>(prop) != NULL && prop->getName() == "viewLabelPosition")
-    static_cast<IntegerProperty*>(prop)->setNodeValue(n,v.value<LabelPosition::LabelPositions>());
   else if (dynamic_cast<BooleanVectorProperty*>(prop) != NULL)
     static_cast<BooleanVectorProperty*>(prop)->setNodeValue(n,v.value<QVector<bool> >().toStdVector());
 
@@ -369,23 +397,33 @@ bool GraphModel::setNodeValue(unsigned int id, PropertyInterface * prop, QVarian
 QVariant GraphModel::edgeValue(unsigned int id, PropertyInterface * prop) {
   edge e(id);
 
-  if (dynamic_cast<IntegerProperty*>(prop) != NULL && prop->getName() == "viewShape")
-    return QVariant::fromValue<EdgeShape::EdgeShapes>(static_cast<EdgeShape::EdgeShapes>(static_cast<IntegerProperty*>(prop)->getEdgeValue(e)));
-  else if (dynamic_cast<IntegerProperty*>(prop) != NULL && prop->getName() == "viewTgtAnchorShape")
-    return QVariant::fromValue<EdgeExtremityShape::EdgeExtremityShapes>(static_cast<EdgeExtremityShape::EdgeExtremityShapes>(static_cast<IntegerProperty*>(prop)->getEdgeValue(e)));
-  else if (dynamic_cast<IntegerProperty*>(prop) != NULL && prop->getName() == "viewSrcAnchorShape")
-    return QVariant::fromValue<EdgeExtremityShape::EdgeExtremityShapes>(static_cast<EdgeExtremityShape::EdgeExtremityShapes>(static_cast<IntegerProperty*>(prop)->getEdgeValue(e)));
+  if (dynamic_cast<IntegerProperty*>(prop) != NULL) {
+    if (prop->getName() == "viewShape")
+      return QVariant::fromValue<EdgeShape::EdgeShapes>(static_cast<EdgeShape::EdgeShapes>(static_cast<IntegerProperty*>(prop)->getEdgeValue(e)));
+
+    if (prop->getName() == "viewTgtAnchorShape")
+      return QVariant::fromValue<EdgeExtremityShape::EdgeExtremityShapes>(static_cast<EdgeExtremityShape::EdgeExtremityShapes>(static_cast<IntegerProperty*>(prop)->getEdgeValue(e)));
+
+    if (prop->getName() == "viewSrcAnchorShape")
+      return QVariant::fromValue<EdgeExtremityShape::EdgeExtremityShapes>(static_cast<EdgeExtremityShape::EdgeExtremityShapes>(static_cast<IntegerProperty*>(prop)->getEdgeValue(e)));
+
+    if (prop->getName() == "viewLabelPosition")
+      return QVariant::fromValue<LabelPosition::LabelPositions>(static_cast<LabelPosition::LabelPositions>(static_cast<IntegerProperty*>(prop)->getEdgeValue(e)));
+
+    return QVariant::fromValue<int>(static_cast<IntegerProperty*>(prop)->getEdgeValue(e));
+  }
   else if (dynamic_cast<StringProperty*>(prop) != NULL) {
     if (prop->getName() == "viewFont")
       return QVariant::fromValue<TulipFont>(TulipFont::fromFile(QString::fromUtf8(static_cast<StringProperty*>(prop)->getEdgeValue(e).c_str())));
 
+    if (prop->getName() == "viewFontAwesomeIcon")
+      return QVariant::fromValue<TulipFontAwesomeIcon>(TulipFontAwesomeIcon(QString::fromUtf8(static_cast<StringProperty*>(prop)->getEdgeValue(e).c_str())));
+
     if (prop->getName() == "viewTexture")
       return QVariant::fromValue<TulipFileDescriptor>(TulipFileDescriptor(QString::fromUtf8(static_cast<StringProperty*>(prop)->getEdgeValue(e).c_str()),TulipFileDescriptor::File));
 
     return QVariant::fromValue<QString>(QString::fromUtf8(static_cast<StringProperty*>(prop)->getEdgeValue(e).c_str()));
   }
-  else if (dynamic_cast<IntegerProperty*>(prop) != NULL && prop->getName() == "viewLabelPosition")
-    return QVariant::fromValue<LabelPosition::LabelPositions>(static_cast<LabelPosition::LabelPositions>(static_cast<IntegerProperty*>(prop)->getEdgeValue(e)));
   else if (dynamic_cast<BooleanVectorProperty*>(prop) != NULL)
     return QVariant::fromValue<QVector<bool> >(QVector<bool>::fromStdVector(static_cast<BooleanVectorProperty*>(prop)->getEdgeValue(e)));
 
@@ -395,23 +433,33 @@ QVariant GraphModel::edgeValue(unsigned int id, PropertyInterface * prop) {
 
 #define GET_EDGE_DEFAULT_VALUE(PROP,TYPE) else if (dynamic_cast<PROP*>(prop) != NULL) return QVariant::fromValue< TYPE >(static_cast<PROP*>(prop)->getEdgeDefaultValue())
 QVariant GraphModel::edgeDefaultValue(PropertyInterface * prop) {
-  if (dynamic_cast<IntegerProperty*>(prop) != NULL && prop->getName() == "viewShape")
-    return QVariant::fromValue<EdgeShape::EdgeShapes>(static_cast<EdgeShape::EdgeShapes>(static_cast<IntegerProperty*>(prop)->getEdgeDefaultValue()));
-  else if (dynamic_cast<IntegerProperty*>(prop) != NULL && prop->getName() == "viewTgtAnchorShape")
-    return QVariant::fromValue<EdgeExtremityShape::EdgeExtremityShapes>(static_cast<EdgeExtremityShape::EdgeExtremityShapes>(static_cast<IntegerProperty*>(prop)->getEdgeDefaultValue()));
-  else if (dynamic_cast<IntegerProperty*>(prop) != NULL && prop->getName() == "viewSrcAnchorShape")
-    return QVariant::fromValue<EdgeExtremityShape::EdgeExtremityShapes>(static_cast<EdgeExtremityShape::EdgeExtremityShapes>(static_cast<IntegerProperty*>(prop)->getEdgeDefaultValue()));
+  if (dynamic_cast<IntegerProperty*>(prop) != NULL) {
+    if (prop->getName() == "viewShape")
+      return QVariant::fromValue<EdgeShape::EdgeShapes>(static_cast<EdgeShape::EdgeShapes>(static_cast<IntegerProperty*>(prop)->getEdgeDefaultValue()));
+
+    if (prop->getName() == "viewTgtAnchorShape")
+      return QVariant::fromValue<EdgeExtremityShape::EdgeExtremityShapes>(static_cast<EdgeExtremityShape::EdgeExtremityShapes>(static_cast<IntegerProperty*>(prop)->getEdgeDefaultValue()));
+
+    if (prop->getName() == "viewSrcAnchorShape")
+      return QVariant::fromValue<EdgeExtremityShape::EdgeExtremityShapes>(static_cast<EdgeExtremityShape::EdgeExtremityShapes>(static_cast<IntegerProperty*>(prop)->getEdgeDefaultValue()));
+
+    if (prop->getName() == "viewLabelPosition")
+      return QVariant::fromValue<LabelPosition::LabelPositions>(static_cast<LabelPosition::LabelPositions>(static_cast<IntegerProperty*>(prop)->getEdgeDefaultValue()));
+
+    return QVariant::fromValue<int>(static_cast<IntegerProperty*>(prop)->getEdgeDefaultValue());
+  }
   else if (dynamic_cast<StringProperty*>(prop) != NULL) {
     if (prop->getName() == "viewFont")
       return QVariant::fromValue<TulipFont>(TulipFont::fromFile(static_cast<StringProperty*>(prop)->getEdgeDefaultValue().c_str()));
 
+    if (prop->getName() == "viewFontAwesomeIcon")
+      return QVariant::fromValue<TulipFontAwesomeIcon>(TulipFontAwesomeIcon(QString::fromUtf8(static_cast<StringProperty*>(prop)->getEdgeDefaultValue().c_str())));
+
     if (prop->getName() == "viewTexture")
       return QVariant::fromValue<TulipFileDescriptor>(TulipFileDescriptor(QString::fromUtf8(static_cast<StringProperty*>(prop)->getEdgeDefaultValue().c_str()),TulipFileDescriptor::File));
 
     return QVariant::fromValue<QString>(QString::fromUtf8(static_cast<StringProperty*>(prop)->getEdgeDefaultValue().c_str()));
   }
-  else if (dynamic_cast<IntegerProperty*>(prop) != NULL && prop->getName() == "viewLabelPosition")
-    return QVariant::fromValue<LabelPosition::LabelPositions>(static_cast<LabelPosition::LabelPositions>(static_cast<IntegerProperty*>(prop)->getEdgeDefaultValue()));
   else if (dynamic_cast<BooleanVectorProperty*>(prop) != NULL)
     return QVariant::fromValue<QVector<bool> >(QVector<bool>::fromStdVector(static_cast<BooleanVectorProperty*>(prop)->getEdgeDefaultValue()));
 
@@ -423,22 +471,32 @@ QVariant GraphModel::edgeDefaultValue(PropertyInterface * prop) {
 bool GraphModel::setEdgeValue(unsigned int id, PropertyInterface* prop, QVariant v) {
   edge e(id);
 
-  if (dynamic_cast<IntegerProperty*>(prop) != NULL && prop->getName() == "viewShape")
-    static_cast<IntegerProperty*>(prop)->setEdgeValue(e,v.value<EdgeShape::EdgeShapes>());
-  else if (dynamic_cast<IntegerProperty*>(prop) != NULL && prop->getName() == "viewTgtAnchorShape")
-    static_cast<IntegerProperty*>(prop)->setEdgeValue(e,v.value<EdgeExtremityShape::EdgeExtremityShapes>());
-  else if (dynamic_cast<IntegerProperty*>(prop) != NULL && prop->getName() == "viewSrcAnchorShape")
-    static_cast<IntegerProperty*>(prop)->setEdgeValue(e,v.value<EdgeExtremityShape::EdgeExtremityShapes>());
+  if (dynamic_cast<IntegerProperty*>(prop) != NULL) {
+    if (prop->getName() == "viewShape")
+      static_cast<IntegerProperty*>(prop)->setEdgeValue(e,v.value<EdgeShape::EdgeShapes>());
+
+    else if (prop->getName() == "viewTgtAnchorShape")
+      static_cast<IntegerProperty*>(prop)->setEdgeValue(e,v.value<EdgeExtremityShape::EdgeExtremityShapes>());
+
+    else if (prop->getName() == "viewSrcAnchorShape")
+      static_cast<IntegerProperty*>(prop)->setEdgeValue(e,v.value<EdgeExtremityShape::EdgeExtremityShapes>());
+
+    else if (prop->getName() == "viewLabelPosition")
+      static_cast<IntegerProperty*>(prop)->setEdgeValue(e,v.value<LabelPosition::LabelPositions>());
+
+    else
+      static_cast<IntegerProperty*>(prop)->setEdgeValue(e,v.value<int>());
+  }
   else if (dynamic_cast<StringProperty*>(prop) != NULL) {
     if (prop->getName() == "viewFont")
       static_cast<StringProperty*>(prop)->setEdgeValue(e, std::string(v.value<TulipFont>().fontFile().toUtf8().data()));
+    else if (prop->getName() == "viewFontAwesomeIcon")
+      static_cast<StringProperty*>(prop)->setEdgeValue(e,std::string(v.value<TulipFontAwesomeIcon>().iconName.toUtf8().data()));
     else if (prop->getName() == "viewTexture")
       static_cast<StringProperty*>(prop)->setEdgeValue(e,std::string(v.value<TulipFileDescriptor>().absolutePath.toUtf8().data()));
     else
       static_cast<StringProperty*>(prop)->setEdgeValue(e, std::string(v.value<QString>().toUtf8().data()));
   }
-  else if (dynamic_cast<IntegerProperty*>(prop) != NULL && prop->getName() == "viewLabelPosition")
-    static_cast<IntegerProperty*>(prop)->setEdgeValue(e,v.value<LabelPosition::LabelPositions>());
   else if (dynamic_cast<BooleanVectorProperty*>(prop) != NULL)
     static_cast<BooleanVectorProperty*>(prop)->setEdgeValue(e, v.value<QVector<bool> >().toStdVector());
 
@@ -450,22 +508,35 @@ bool GraphModel::setEdgeValue(unsigned int id, PropertyInterface* prop, QVariant
 }
 #define SET_ALL_EDGE_VALUE(PROP,TYPE) else if (dynamic_cast<PROP*>(prop) != NULL) static_cast<PROP*>(prop)->setAllEdgeValue(v.value< TYPE >())
 bool GraphModel::setAllEdgeValue(PropertyInterface* prop, QVariant v) {
-  if (dynamic_cast<IntegerProperty*>(prop) != NULL && prop->getName() == "viewShape")
-    static_cast<IntegerProperty*>(prop)->setAllEdgeValue(v.value<EdgeShape::EdgeShapes>());
-  else if (dynamic_cast<IntegerProperty*>(prop) != NULL && prop->getName() == "viewTgtAnchorShape")
-    static_cast<IntegerProperty*>(prop)->setAllEdgeValue(v.value<EdgeExtremityShape::EdgeExtremityShapes>());
-  else if (dynamic_cast<IntegerProperty*>(prop) != NULL && prop->getName() == "viewSrcAnchorShape")
-    static_cast<IntegerProperty*>(prop)->setAllEdgeValue(v.value<EdgeExtremityShape::EdgeExtremityShapes>());
+  if (dynamic_cast<IntegerProperty*>(prop) != NULL) {
+    if (prop->getName() == "viewShape")
+      static_cast<IntegerProperty*>(prop)->setAllEdgeValue(v.value<EdgeShape::EdgeShapes>());
+
+    else if (prop->getName() == "viewTgtAnchorShape")
+      static_cast<IntegerProperty*>(prop)->setAllEdgeValue(v.value<EdgeExtremityShape::EdgeExtremityShapes>());
+
+    else if (prop->getName() == "viewSrcAnchorShape")
+      static_cast<IntegerProperty*>(prop)->setAllEdgeValue(v.value<EdgeExtremityShape::EdgeExtremityShapes>());
+
+    else if (prop->getName() == "viewLabelPosition")
+      static_cast<IntegerProperty*>(prop)->setAllEdgeValue(v.value<LabelPosition::LabelPositions>());
+
+    else
+      static_cast<IntegerProperty*>(prop)->setAllEdgeValue(v.value<int>());
+  }
   else if (dynamic_cast<StringProperty*>(prop) != NULL) {
     if (prop->getName() == "viewFont")
       static_cast<StringProperty*>(prop)->setAllEdgeValue(std::string(v.value<TulipFont>().fontFile().toUtf8().data()));
+
+    else if (prop->getName() == "viewFontAwesomeIcon")
+      static_cast<StringProperty*>(prop)->setAllEdgeValue(std::string(v.value<TulipFontAwesomeIcon>().iconName.toUtf8().data()));
+
     else if (prop->getName() == "viewTexture")
       static_cast<StringProperty*>(prop)->setAllEdgeValue(std::string(v.value<TulipFileDescriptor>().absolutePath.toUtf8().data()));
+
     else
       static_cast<StringProperty*>(prop)->setAllEdgeValue(std::string(v.value<QString>().toUtf8().data()));
   }
-  else if (dynamic_cast<IntegerProperty*>(prop) != NULL && prop->getName() == "viewLabelPosition")
-    static_cast<IntegerProperty*>(prop)->setAllEdgeValue(v.value<LabelPosition::LabelPositions>());
   else if (dynamic_cast<BooleanVectorProperty*>(prop) != NULL)
     static_cast<BooleanVectorProperty*>(prop)->setAllEdgeValue(v.value<QVector<bool> >().toStdVector());
 
