@@ -3,7 +3,7 @@
  * This file is part of Tulip (www.tulip-software.org)
  *
  * Authors: David Auber and the Tulip development Team
- * from LaBRI, University of Bordeaux 1 and Inria Bordeaux - Sud Ouest
+ * from LaBRI, University of Bordeaux
  *
  * Tulip is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License
@@ -99,7 +99,7 @@ void SceneConfigWidget::resetChanges() {
 
   // NODES
   delete _ui->labelsOrderingCombo->model();
-  GraphPropertiesModel<DoubleProperty>* model = new GraphPropertiesModel<DoubleProperty>(trUtf8("Disable ordering"),graph);
+  GraphPropertiesModel<NumericProperty>* model = new GraphPropertiesModel<NumericProperty>(trUtf8("Disable ordering"),graph);
   _ui->labelsOrderingCombo->setModel(model);
 
   if (renderingParameters->getElementOrderingProperty() == NULL)
@@ -108,6 +108,7 @@ void SceneConfigWidget::resetChanges() {
     _ui->labelsOrderingCombo->setCurrentIndex(model->rowOf(renderingParameters->getElementOrderingProperty()));
 
   _ui->labelsFitCheck->setChecked(renderingParameters->isLabelScaled());
+  _ui->labelsBillboardedCheck->setChecked(renderingParameters->getLabelsAreBillboarded());
   _ui->fixedFontSizeRB->setChecked(renderingParameters->isLabelFixedFontSize());
   _ui->dynamicFontSizeRB->setChecked(!renderingParameters->isLabelFixedFontSize());
   _ui->labelsDensitySlider->setValue(renderingParameters->getLabelsDensity());
@@ -171,11 +172,12 @@ void SceneConfigWidget::applySettings() {
   if (_ui->labelsOrderingCombo->currentIndex()==0)
     renderingParameters->setElementOrderingProperty(NULL);
   else {
-    GraphPropertiesModel<DoubleProperty>* model = static_cast<GraphPropertiesModel<DoubleProperty> *>(_ui->labelsOrderingCombo->model());
-    renderingParameters->setElementOrderingProperty(dynamic_cast<DoubleProperty*>(model->index(_ui->labelsOrderingCombo->currentIndex(),0).data(TulipModel::PropertyRole).value<PropertyInterface*>()));
+    GraphPropertiesModel<NumericProperty>* model = static_cast<GraphPropertiesModel<NumericProperty> *>(_ui->labelsOrderingCombo->model());
+    renderingParameters->setElementOrderingProperty(dynamic_cast<NumericProperty*>(model->index(_ui->labelsOrderingCombo->currentIndex(),0).data(TulipModel::PropertyRole).value<PropertyInterface*>()));
   }
 
   renderingParameters->setLabelScaled(_ui->labelsFitCheck->isChecked());
+  renderingParameters->setLabelsAreBillboarded(_ui->labelsBillboardedCheck->isChecked());
   renderingParameters->setLabelFixedFontSize(_ui->fixedFontSizeRB->isChecked());
   renderingParameters->setLabelsDensity(_ui->labelsDensitySlider->value());
   renderingParameters->setMinSizeOfLabel(_ui->labelSizesSpanSlider->lowerValue());
