@@ -43,7 +43,6 @@
 #include <tulip/TulipMimes.h>
 #include <tulip/TlpQtTools.h>
 
-
 using namespace tlp;
 
 // helper class
@@ -73,6 +72,35 @@ public:
   }
 };
 
+#ifdef WIN32
+
+class CustomTabBar : public QTabBar {
+
+public:
+
+  CustomTabBar(QWidget *parent = 0) : QTabBar(parent) {}
+
+protected:
+
+  QSize tabSizeHint(int index) const {
+    int width = QTabBar::tabSizeHint(index).width();
+    return QSize(width, fontMetrics().width(tabText(index))*2 + iconSize().width());
+  }
+
+};
+
+class CustomTabWidget : public QTabWidget {
+
+public:
+
+  CustomTabWidget(QWidget *parent=0) : QTabWidget(parent) {
+    setTabBar(new CustomTabBar());
+  }
+
+};
+
+#endif
+
 // ========================
 
 WorkspacePanel::WorkspacePanel(tlp::View* view, QWidget *parent)
@@ -103,10 +131,16 @@ WorkspacePanel::~WorkspacePanel() {
   }
 
   delete _ui;
+  // because of possible mis-synchronization of Qt events
+  // set it to NULL
+  // to avoid any invalid read in the eventFilter method
+  _ui = NULL;
 
   if (_view != NULL) {
     disconnect(_view,SIGNAL(destroyed()),this,SLOT(viewDestroyed()));
     delete _view;
+    // same as above
+    _view = NULL;
   }
 }
 void WorkspacePanel::viewDestroyed() {
@@ -166,7 +200,11 @@ void WorkspacePanel::setView(tlp::View* view) {
   if (_view->configurationWidgets().empty())
     return;
 
+#ifdef WIN32
+  QTabWidget* viewConfigurationTabs = new CustomTabWidget();
+#else
   QTabWidget* viewConfigurationTabs = new QTabWidget();
+#endif
   viewConfigurationTabs->setTabsClosable(true);
   connect(viewConfigurationTabs,SIGNAL(tabCloseRequested(int)),this,SLOT(hideConfigurationTab()));
   viewConfigurationTabs->setTabPosition(QTabWidget::West);
@@ -188,6 +226,51 @@ void WorkspacePanel::setView(tlp::View* view) {
   resetInteractorsScrollButtonsVisibility();
 }
 
+void WorkspacePanel::showEvent(QShowEvent *event) {
+  QFrame::showEvent(event);
+// Workaround to avoid a Qt5 bug :
+// After the panels containing QGraphicsView objects were rearranged in the workspace,
+// some events were no more sent to the QGraphicsWidget objects embedded in the asoociated QGraphicScene objects.
+// Those events are necessary for important parts of the view GUI (context menu, keyboard focus) to work correctly.
+// So add a hack that, each time a view is shown, creates a new QGraphicsScene object
+// and refill it with QGraphicsItem objects contained in the previous one.
+// Seems to be the only way to workaround that issue.
+#if (QT_VERSION >= QT_VERSION_CHECK(5, 0, 0))
+
+  if (_view->graphicsView()->scene()) {
+    // first remove central item of the scene and its children
+    _view->graphicsView()->scene()->removeItem(_view->centralItem());
+    // get remaining items (if any) that were not descendant of the central item
+    // and remove it from the scene
+    QList<QGraphicsItem *> items = _view->graphicsView()->scene()->items();
+
+    for (int i = 0 ; i < items.size() ; ++i) {
+      _view->graphicsView()->scene()->removeItem(items.at(i));
+    }
+
+    // get old scene pointer for further deletion
+    QGraphicsScene *oldScene = _view->graphicsView()->scene();
+    QGraphicsScene *newScene = new QGraphicsScene();
+    newScene->setSceneRect(oldScene->sceneRect());
+    // create a new QGraphicsScene and set it in the QGraphicsView
+    _view->graphicsView()->setScene(newScene);
+    // restore central item and its children in the new scene
+    _view->graphicsView()->scene()->addItem(_view->centralItem());
+
+    // restore remaining items in the new scene
+    for (int i = 0 ; i < items.size() ; ++i) {
+      _view->graphicsView()->scene()->addItem(items.at(i));
+    }
+
+    // set event filter for the new scene
+    _view->graphicsView()->scene()->installEventFilter(this);
+    // delete old scene
+    delete oldScene;
+  }
+
+#endif
+}
+
 bool WorkspacePanel::eventFilter(QObject* obj, QEvent* ev) {
   if (_viewConfigurationWidgets != NULL && _view != NULL) {
     if (ev->type() == QEvent::GraphicsSceneContextMenu) {
@@ -205,16 +288,20 @@ bool WorkspacePanel::eventFilter(QObject* obj, QEvent* ev) {
     }
   }
 
-  if (obj == _ui->interactorsFrame && ev->type() == QEvent::Wheel) {
-    if (static_cast<QWheelEvent*>(ev)->delta()>0)
-      scrollInteractorsLeft();
-    else
-      scrollInteractorsRight();
-  }
+  // we must check _ui has not been deleted
+  // because of possible mis-synchronization of Qt events
+  if (_ui) {
+    if (obj == _ui->interactorsFrame && ev->type() == QEvent::Wheel) {
+      if (static_cast<QWheelEvent*>(ev)->delta()>0)
+        scrollInteractorsLeft();
+      else
+        scrollInteractorsRight();
+    }
 
 
-  if (obj == _ui->graphCombo && ev->type() == QEvent::Wheel) {
-    return true;
+    if (obj == _ui->graphCombo && ev->type() == QEvent::Wheel) {
+      return true;
+    }
   }
 
   return QWidget::eventFilter(obj,ev);
