@@ -38,10 +38,8 @@ GlComposite::~GlComposite() {
 void GlComposite::addLayerParent(GlLayer *layer) {
   layerParents.push_back(layer);
 
-  GlComposite *composite;
-
   for(list<GlSimpleEntity *>::iterator it = _sortedElements.begin(); it != _sortedElements.end(); ++it) {
-    composite=dynamic_cast<GlComposite*>(*it);
+    GlComposite* composite=dynamic_cast<GlComposite*>(*it);
 
     if(composite)
       composite->addLayerParent(layer);
@@ -56,10 +54,8 @@ void GlComposite::removeLayerParent(GlLayer *layer) {
     }
   }
 
-  GlComposite *composite;
-
   for(list<GlSimpleEntity *>::iterator it = _sortedElements.begin(); it != _sortedElements.end(); ++it) {
-    composite=dynamic_cast<GlComposite*>(*it);
+    GlComposite* composite=dynamic_cast<GlComposite*>(*it);
 
     if(composite)
       composite->removeLayerParent(layer);
@@ -80,21 +76,17 @@ void GlComposite::reset(bool deleteElems) {
         (*it2)->getScene()->notifyDeletedEntity(*it);
     }
 
-    if (deleteElems) {
+    (*it)->removeParent(this);
+
+    for(vector<GlLayer*>::iterator itLayers=layerParents.begin(); itLayers!=layerParents.end(); ++itLayers) {
+      GlComposite *composite=dynamic_cast<GlComposite*>(*it);
+
+      if(composite)
+        composite->removeLayerParent(*itLayers);
+    }
+
+    if (deleteElems)
       delete (*it);
-    }
-    else {
-      (*it)->removeParent(this);
-
-      GlComposite *composite;
-
-      for(vector<GlLayer*>::iterator itLayers=layerParents.begin(); itLayers!=layerParents.end(); ++itLayers) {
-        composite=dynamic_cast<GlComposite*>(*it);
-
-        if(composite)
-          composite->removeLayerParent(*itLayers);
-      }
-    }
   }
 
   elements.clear();
