@@ -87,7 +87,8 @@ struct entityWithDistanceCompare {
 //====================================================
 
 GlScene::GlScene(GlLODCalculator *calculator)
-  :backgroundColor(255, 255, 255, 255),viewOrtho(true),glGraphComposite(NULL),graphLayer(NULL), clearBufferAtDraw(true),inDraw(false) {
+  : backgroundColor(255, 255, 255, 255),viewOrtho(true),glGraphComposite(NULL),
+    graphLayer(NULL), clearBufferAtDraw(true), inDraw(false), clearDepthBufferAtDraw(true), clearStencilBufferAtDraw(true) {
 
   if(calculator!=NULL)
     lodCalculator=calculator;
@@ -109,29 +110,46 @@ void GlScene::initGlParameters() {
   OpenGlConfigManager::getInst().initExtensions();
 
   glViewport(viewport[0],viewport[1],viewport[2],viewport[3]);
+  glScissor(viewport[0],viewport[1],viewport[2],viewport[3]);
 
   glEnable(GL_BLEND);
   glBlendFunc(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
   glLineWidth(1.0);
   glPointSize(1.0);
   glEnable(GL_CULL_FACE);
+  glEnable(GL_SCISSOR_TEST);
+  glDepthFunc(GL_LEQUAL);
   glEnable(GL_DEPTH_TEST);
+  glClearStencil(0xFFFF);
+  glStencilOp(GL_KEEP,GL_KEEP,GL_REPLACE);
   glEnable(GL_STENCIL_TEST);
   glEnable(GL_NORMALIZE);
   glShadeModel(GL_SMOOTH);
-  glDepthFunc(GL_LEQUAL );
   glPolygonMode(GL_FRONT, GL_FILL);
   glColorMask(1, 1, 1, 1);
   glIndexMask(UINT_MAX);
-  glClearStencil(0xFFFF);
-  glStencilOp(GL_KEEP,GL_KEEP,GL_REPLACE);
+
+
+  if (OpenGlConfigManager::getInst().antiAliasing()) {
+    OpenGlConfigManager::getInst().activateAntiAliasing();
+  }
+  else {
+    OpenGlConfigManager::getInst().desactivateAntiAliasing();
+  }
 
   if (clearBufferAtDraw) {
     glClearColor(backgroundColor.getRGL(), backgroundColor.getGGL(), backgroundColor.getBGL(), backgroundColor.getAGL());
     glClear(GL_COLOR_BUFFER_BIT);
   }
 
-  glClear(GL_DEPTH_BUFFER_BIT | GL_STENCIL_BUFFER_BIT);
+  if (clearDepthBufferAtDraw) {
+    glClear(GL_DEPTH_BUFFER_BIT);
+  }
+
+  if (clearStencilBufferAtDraw) {
+    glClear(GL_STENCIL_BUFFER_BIT);
+  }
+
   glDisable(GL_TEXTURE_2D);
 
 #ifndef NDEBUG
@@ -151,13 +169,6 @@ void GlScene::draw() {
 
   initGlParameters();
 
-  if (OpenGlConfigManager::getInst().antiAliasing()) {
-    OpenGlConfigManager::getInst().activateAntiAliasing();
-  }
-  else {
-    OpenGlConfigManager::getInst().desactivateAntiAliasing();
-  }
-
   /**********************************************************************
   LOD Compute
   **********************************************************************/
@@ -501,7 +512,7 @@ void GlScene::computeAjustSceneToSize(int width, int height, Coord *center, Coor
   }
 
   if ((dx==0) && (dy==0) && (dz==0))
-    dx = dy = dz = 10.0;
+    dx = dy = /*dz =*/ 10.0;
 
   double wdx=width/dxZoomed;
   double hdy=height/dyZoomed;
@@ -763,16 +774,17 @@ bool GlScene::selectEntities(RenderingEntitiesFlag type,int x, int y, int w, int
     glDisable(GL_STENCIL_TEST);
 
     map<unsigned int, SelectedEntity> idToEntity;
-    unsigned int id=1;
 
     if(type & RenderingSimpleEntities) {
+      unsigned int id=1;
+
       for(vector<SimpleEntityLODUnit>::const_iterator it = itLayer->simpleEntitiesLODVector.begin(); it!=itLayer->simpleEntitiesLODVector.end(); ++it) {
         if(it->lod<0)
           continue;
 
         idToEntity[id]=SelectedEntity(it->entity);
         glLoadName(id);
-        id++;
+        ++id;
         it->entity->draw(20.,camera);
       }
     }
