@@ -1,22 +1,3 @@
-/*
- *
- * This file is part of Tulip (www.tulip-software.org)
- *
- * Authors: David Auber and the Tulip development Team
- * from LaBRI, University of Bordeaux
- *
- * Tulip is free software; you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License
- * as published by the Free Software Foundation, either version 3
- * of the License, or (at your option) any later version.
- *
- * Tulip is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
- * See the GNU General Public License for more details.
- *
- */
-
 /**
  *
  * This file is part of Tulip (www.tulip-software.org)
@@ -47,6 +28,7 @@ typedef _object PyObject;
 #include <tulip/PythonCppTypesConverter.h>
 #include <tulip/Graph.h>
 
+#include <QObject>
 #include <QVector>
 #include <QSet>
 #include <QString>
@@ -57,7 +39,9 @@ class QTextBrowser;
 
 namespace tlp {
 
-class TLP_PYTHON_SCOPE PythonInterpreter {
+class TLP_PYTHON_SCOPE PythonInterpreter : public QObject {
+
+  Q_OBJECT
 
   PythonInterpreter();
   ~PythonInterpreter();
@@ -208,6 +192,12 @@ public :
 
   PyObject* evalPythonStatement(const QString &pythonStatement);
 
+  void clearTracebacks();
+
+signals:
+
+  void scriptExecutionPaused();
+
 };
 
 #include "PythonInterpreter.cxx"
