@@ -22,6 +22,8 @@
 #include "tulip/PythonCodeHighlighter.h"
 #include "tulip/ParenMatcherHighlighter.h"
 
+#include <tulip/Perspective.h>
+
 #include <QTextStream>
 #include <QPainter>
 #include <QTextBlock>
@@ -80,11 +82,11 @@ private:
 
 AutoCompletionList::AutoCompletionList(PythonCodeEditor *parent) : QListWidget(parent), _codeEditor(parent) {
 #if defined(__APPLE__)
-  setWindowFlags(Qt::Popup|Qt::FramelessWindowHint);
+  setWindowFlags((Qt::WindowFlags) Qt::Popup|Qt::FramelessWindowHint);
 #elif QT_VERSION >= 0x040500
-  setWindowFlags(Qt::ToolTip);
+  setWindowFlags((Qt::WindowFlags) Qt::ToolTip);
 #else
-  setWindowFlags(Qt::Tool|Qt::FramelessWindowHint);
+  setWindowFlags((Qt::WindowFlags) Qt::Tool|Qt::FramelessWindowHint);
 #endif
   setAttribute(Qt::WA_StaticContents);
   setFrameShape(StyledPanel);
@@ -93,6 +95,9 @@ AutoCompletionList::AutoCompletionList(PythonCodeEditor *parent) : QListWidget(p
   installEventFilter(&keyboardFocusEventFilter);
   _activated = false;
   _wasActivated = false;
+  setToolTip("Use up and down arrow keys to navigate through the list (or use the mouse wheel).\n"
+             "Hit Enter key to insert the current selected item (or double click on it).\n"
+             "Hit Escape key to cancel the autocompletion list and hide it.");
 }
 
 void AutoCompletionList::keyPressEvent(QKeyEvent *e) {
@@ -205,6 +210,8 @@ void AutoCompletionList::insertSelectedItem() {
       }
     }
   }
+
+  _codeEditor->setFocus();
 }
 
 void AutoCompletionList::showEvent (QShowEvent * event) {
@@ -216,11 +223,16 @@ void AutoCompletionList::showEvent (QShowEvent * event) {
 void AutoCompletionList::hideEvent (QHideEvent * event) {
   QListWidget::hideEvent(event);
   releaseKeyboard();
+  _codeEditor->setFocus();
   _activated = false;
 }
 
 
-bool AutoCompletionList::eventFilter(QObject *, QEvent *event) {
+bool AutoCompletionList::eventFilter(QObject *obj, QEvent *event) {
+  if (obj != _codeEditor && obj != _codeEditor->mainWindow()) {
+    return false;
+  }
+
   if (!_wasActivated && (event->type() == QEvent::WindowDeactivate || event->type() == QEvent::Hide)) {
     _wasActivated = _activated;
     hide();
@@ -449,6 +461,7 @@ PythonCodeEditor::PythonCodeEditor(QWidget *parent) : QPlainTextEdit(parent), _h
   setCommentShortcutsActivated(true);
   setIndentShortcutsActivated(true);
   setWordWrapMode(QTextOption::NoWrap);
+  setFocusPolicy(Qt::ClickFocus);
   QTextCharFormat format = currentCharFormat();
 #if defined(WIN32)
   _currentFont.setFamily("Courier New");
@@ -482,20 +495,25 @@ PythonCodeEditor::PythonCodeEditor(QWidget *parent) : QPlainTextEdit(parent), _h
   // Hack to get a pointer on the main window
   // in order for the autocompletion dialog to catch
   // window activate/desactivate events
-  QMainWindow *mainWindow = NULL;
-  QWidget *parente = dynamic_cast<QWidget*>(this->parent());
+  if (Perspective::instance()) {
+    _mainWindow = Perspective::instance()->mainWindow();
+  }
+  else {
+    QWidget *parente = dynamic_cast<QWidget*>(this->parent());
 
-  while (parente) {
-    mainWindow = dynamic_cast<QMainWindow *>(parente);
+    while (parente) {
+      _mainWindow = dynamic_cast<QMainWindow *>(parente);
 
-    if (mainWindow)
-      break;
+      if (_mainWindow)
+        break;
 
-    parente = dynamic_cast<QWidget *>(parente->parent());
+      parente = dynamic_cast<QWidget *>(parente->parent());
+    }
   }
 
-  if (mainWindow)
-    mainWindow->installEventFilter(_autoCompletionList);
+  if (_mainWindow) {
+    _mainWindow->installEventFilter(_autoCompletionList);
+  }
 
   installEventFilter(_autoCompletionList);
 
@@ -966,6 +984,7 @@ void PythonCodeEditor::highlightErrors() {
 }
 
 void PythonCodeEditor::keyPressEvent (QKeyEvent * e) {
+
 #ifdef __APPLE__
   Qt::KeyboardModifiers modifier = Qt::MetaModifier;
 #else
@@ -1262,10 +1281,7 @@ void PythonCodeEditor::updateAutoCompletionList(bool dotContext) {
   }
   _autoCompletionList->sortItems();
 
-  if (_autoCompletionList->count() == 0)
-    _autoCompletionList->hide();
-  else
-    _autoCompletionList->setCurrentRow(0);
+  _autoCompletionList->setCurrentRow(0);
 
 }
 
