@@ -696,6 +696,8 @@ bool PythonInterpreter::runGraphScript(const QString &module, const QString &fun
 
   holdGIL();
 
+  clearTracebacks();
+
   bool ret = true;
   scriptPaused = false;
 
@@ -1053,7 +1055,12 @@ void PythonInterpreter::clearOutputBuffers() {
 }
 
 void PythonInterpreter::pauseCurrentScript(const bool pause) {
+  bool wasPaused = scriptPaused;
   scriptPaused = pause;
+
+  if (!wasPaused && scriptPaused) {
+    emit scriptExecutionPaused();
+  }
 }
 
 bool PythonInterpreter::isScriptPaused() const {
@@ -1117,3 +1124,13 @@ QString PythonInterpreter::readLineFromConsole() {
 
   return "";
 }
+
+void PythonInterpreter::clearTracebacks() {
+  QString pythonCode = "import sys\n";
+#if PY_MAJOR_VERSION < 3
+  pythonCode += "sys.exc_clear()\n";
+  pythonCode += "sys.exc_traceback = None\n";
+#endif
+  pythonCode += "sys.last_traceback = None\n";
+  runString(pythonCode);
+}
