@@ -46,8 +46,6 @@
 using namespace std;
 using namespace tlp;
 
-const double MAX_VAL = DBL_MAX;
-
 //============================================
 
 static const char* paramHelp[] = {
@@ -452,7 +450,11 @@ bool EdgeBundling::run() {
       stringstream strm;
       strm << "Computing iteration " << iteration + 1 << "/" << MAX_ITER;
       pluginProgress->setComment(strm.str());
-      pluginProgress->progress(oriGraph->numberOfEdges() - vertexCoverGraph->numberOfEdges(), oriGraph->numberOfEdges());
+      unsigned int i =
+        oriGraph->numberOfEdges() - vertexCoverGraph->numberOfEdges();
+
+      if ((i % 10) == 0)
+        pluginProgress->progress(i, oriGraph->numberOfEdges());
 
       //====================================
       //Select the destination nodes. We do not have to compute
