@@ -3,7 +3,7 @@
  * This file is part of Tulip (www.tulip-software.org)
  *
  * Authors: David Auber and the Tulip development Team
- * from LaBRI, University of Bordeaux 1 and Inria Bordeaux - Sud Ouest
+ * from LaBRI, University of Bordeaux
  *
  * Tulip is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License
@@ -22,7 +22,6 @@
 #include <tulip/ColorProperty.h>
 #include <tulip/GlDisplayListManager.h>
 #include <tulip/GlTextureManager.h>
-#include <tulip/OpenGlConfigManager.h>
 #include <tulip/Graph.h>
 #include <tulip/Glyph.h>
 #include <tulip/GlTools.h>
@@ -96,9 +95,8 @@ void HalfCylinder::draw(node n,float) {
     GlTextureManager::getInst().activateTexture(texturePath+texFile);
   }
 
-  OpenGlConfigManager::getInst().activatePolygonAntiAliasing();
   GlDisplayListManager::getInst().callDisplayList("Halfcylinder_halfcylinder");
-  OpenGlConfigManager::getInst().desactivatePolygonAntiAliasing();
+
   GlTextureManager::getInst().desactivateTexture();
 }
 //=================================================================================================
