@@ -36,14 +36,17 @@
 using namespace std;
 using namespace tlp;
 
-MouseLassoNodesSelectorInteractor::MouseLassoNodesSelectorInteractor(const tlp::PluginContext *):NodeLinkDiagramComponentInteractor(":/i_lasso.png", "Select nodes in a freehand drawn region") {
+MouseLassoNodesSelectorInteractor::MouseLassoNodesSelectorInteractor(const tlp::PluginContext *):NodeLinkDiagramComponentInteractor(":/i_lasso.png", "Select nodes in a freehand drawn region", StandardInteractorPriority::FreeHandSelection) {
   setConfigurationWidgetText(QString("<h3>Select nodes in a freehand drawn region</h3>")+ "<b>Mouse left</b> down begins the freehand drawing of the selection region,<br/><b>Mouse left</b> up ends the drawing of the region.<br/>All the nodes enclosed in the region are selected and the edges linking them too.");
-  setPriority(StandardInteractorPriority::FreeHandSelection);
 }
 
 bool MouseLassoNodesSelectorInteractor::isCompatible(const std::string &viewName) const {
   return ((viewName==NodeLinkDiagramComponent::viewName)
           ||(viewName==ViewName::ScatterPlot2DViewName)
+          ||(viewName==ViewName::HistogramViewName)
+          ||(viewName==ViewName::PixelOrientedViewName)
+          ||(viewName==ViewName::MatrixViewName)
+          ||(viewName==ViewName::ParallelCoordinatesViewName)
          );
 }
 
@@ -59,8 +62,6 @@ MouseLassoNodesSelectorInteractorComponent::MouseLassoNodesSelectorInteractorCom
 
 MouseLassoNodesSelectorInteractorComponent::~MouseLassoNodesSelectorInteractorComponent() {}
 
-const float POINT_RADIUS = 3.;
-
 // found on http://local.wasp.uwa.edu.au/~pbourke/geometry/insidepoly/
 bool pointInsidePolygon(const vector<Coord> &polygon, const Coord &point) {
   unsigned int i, j;
@@ -187,7 +188,7 @@ void MouseLassoNodesSelectorInteractorComponent::selectGraphElementsUnderPolygon
 
 
 bool MouseLassoNodesSelectorInteractorComponent::eventFilter(QObject *obj, QEvent *e) {
-  GlMainWidget *glWidget=(GlMainWidget *)(obj);
+  GlMainWidget *glWidget=static_cast<GlMainWidget *>(obj);
 
   if (!glWidget->hasMouseTracking()) {
     glWidget->setMouseTracking(true);
