@@ -155,13 +155,12 @@ Strahler StrahlerMetric::topSortStrahler(tlp::node n, int &curPref,
 
   result.stacks=result.stacks+result.usedStack;
   //evaluation of tree strahler
-  int tmpDbl;
   int additional=0;
   int available=0;
   strahlerResult.sort();
 
   while (!strahlerResult.empty()) {
-    tmpDbl=strahlerResult.back();
+    int tmpDbl=strahlerResult.back();
     strahlerResult.pop_back();
 
     if (tmpDbl>available) {
@@ -240,6 +239,9 @@ bool StrahlerMetric::run() {
   Iterator<node> *itN=graph->getNodes();
   unsigned int i = 0;
 
+  if (pluginProgress)
+    pluginProgress->showPreview(false);
+
   while (itN->hasNext()) {
     node itn = itN->next();
     tofree[itn] = 0;
@@ -249,7 +251,8 @@ bool StrahlerMetric::run() {
     }
 
     if (allNodes) {
-      if (pluginProgress->progress(i++, graph->numberOfNodes())!=TLP_CONTINUE) break;
+      if (pluginProgress && ((++i % 100) == 0) &&
+          (pluginProgress->progress(i, graph->numberOfNodes())!=TLP_CONTINUE)) break;
 
       switch(computationTypes.getCurrent()) {
       case ALL:
