@@ -31,7 +31,12 @@ public :
   }
 
   bool operator()(const node u, const node v) {
-    return graph->deg(u)>graph->deg(v);
+    unsigned int du = graph->deg(u), dv = graph->deg(v);
+
+    if (du == dv)
+      return u.id > v.id;
+
+    return du > dv;
   }
 };
 
@@ -67,18 +72,17 @@ public:
 
   WelshPowell(const tlp::PluginContext *context):DoubleAlgorithm(context) {}
 
-  bool hasNeightboColoredWith(const node n ,const int color, const MutableContainer<int> &colors) {
+  bool hasNeighbourColoredWith(const node n, const int color) {
     node u;
     forEach(u, graph->getInOutNodes(n))
 
-    if(colors.get(u.id) == color)
+    if (result->getNodeValue(u) == color)
       return true;
 
     return false;
   }
 
   void colorize() {
-
     vector<node> toSort(graph->numberOfNodes());
     node n;
     unsigned int i = 0;
@@ -87,31 +91,43 @@ public:
     CompNodes cmp(graph);
     sort(toSort.begin(),toSort.end(),cmp);
 
-    MutableContainer<int> colors;
-    colors.setAll(-1);
+    result->setAllNodeValue(-1);
     int currentColor = 0;
     unsigned int numberOfColoredNodes = 0;
+    unsigned int minIndex = 0;
+    unsigned int maxIndex = toSort.size();
 
-    while(numberOfColoredNodes != graph->numberOfNodes()) {
+    while (numberOfColoredNodes != graph->numberOfNodes()) {
 #ifndef NDEBUG
-      cerr << "nbColored :"  << numberOfColoredNodes << endl;
+      cout << "nbColored :"  << numberOfColoredNodes << endl;
 #endif
+      unsigned int nextMaxIndex = minIndex;
 
-      for(unsigned int i=0; i < toSort.size(); ++i) {
+      for(unsigned int i= minIndex; i < maxIndex; ++i) {
 #ifndef NDEBUG
-        cerr << "i:" <<  i << endl;
+        cout << "i:" <<  i << endl;
 #endif
+        node n = toSort[i];
 
-        if((colors.get(toSort[i].id) == -1) && (!hasNeightboColoredWith(toSort[i], currentColor, colors))) {
+        if (result->getNodeValue(n) == -1) {
+          if (!hasNeighbourColoredWith(n, currentColor)) {
 #ifndef NDEBUG
-          cerr << "new node found color : " << currentColor << endl;
+            cout << "new node found color : " << currentColor << endl;
 #endif
-          colors.set(toSort[i].id, currentColor);
-          result->setNodeValue(toSort[i], currentColor);
-          ++numberOfColoredNodes;
+            result->setNodeValue(toSort[i], currentColor);
+            ++numberOfColoredNodes;
+
+            if (i == minIndex)
+              ++minIndex;
+          }
+          else
+            nextMaxIndex = i + 1;
         }
+        else if (i == minIndex)
+          ++minIndex;
       }
 
+      maxIndex = nextMaxIndex;
       ++currentColor;
     }
   }
