@@ -18,10 +18,14 @@
  *
  */
 
+#ifdef BUILD_PYTHON_COMPONENTS
 #include <tulip/PythonInterpreter.h>
+#include <tulip/APIDataBase.h>
+#include "PythonPanel.h"
+#include "PythonPluginsIDE.h"
+#endif
 
 #include "GraphPerspective.h"
-#include "DocumentationNavigator.h"
 
 #include <QMessageBox>
 #include <QFileDialog>
@@ -31,6 +35,7 @@
 #include <QDropEvent>
 #include <QUrl>
 #include <QMimeData>
+#include <QTimer>
 
 #include <tulip/TlpTools.h>
 #include <tulip/ImportModule.h>
@@ -40,6 +45,7 @@
 #include <tulip/SimplePluginProgressWidget.h>
 #include <tulip/GraphHierarchiesModel.h>
 #include <tulip/CSVImportWizard.h>
+#include <tulip/DocumentationNavigator.h>
 #include <tulip/GraphModel.h>
 #include <tulip/GraphTableItemDelegate.h>
 #include <tulip/GraphPropertiesModel.h>
@@ -50,7 +56,6 @@
 #include <tulip/PluginLister.h>
 #include <tulip/TlpQtTools.h>
 #include <tulip/TulipProject.h>
-#include <tulip/APIDataBase.h>
 
 #include "ui_GraphPerspectiveMainWindow.h"
 
@@ -90,6 +95,7 @@ void GraphPerspective::reserveDefaultProperties() {
   registerReservedProperty("viewRotation");
   registerReservedProperty("viewSelection");
   registerReservedProperty("viewFont");
+  registerReservedProperty("viewFontAwesomeIcon");
   registerReservedProperty("viewFontSize");
   registerReservedProperty("viewTexture");
   registerReservedProperty("viewBorderColor");
@@ -234,6 +240,21 @@ void GraphPerspective::start(tlp::PluginProgress *progress) {
   reserveDefaultProperties();
   _ui = new Ui::GraphPerspectiveMainWindowData;
   _ui->setupUi(_mainWindow);
+#ifdef BUILD_PYTHON_COMPONENTS
+  _pythonPanel = new PythonPanel();
+  QVBoxLayout *layout = new QVBoxLayout();
+  layout->addWidget(_pythonPanel);
+  layout->setContentsMargins(0,0,0,0);
+  _ui->pythonPanel->setLayout(layout);
+  _developFrame = new PythonPluginsIDE();
+  layout = new QVBoxLayout();
+  layout->addWidget(_developFrame);
+  layout->setContentsMargins(0,0,0,0);
+  _ui->developFrame->setLayout(layout);
+#else
+  _ui->pythonButton->setVisible(false);
+  _ui->developButton->setVisible(false);
+#endif
   currentGraphChanged(NULL);
   _ui->singleModeButton->setEnabled(false);
   _ui->singleModeButton->hide();
@@ -317,9 +338,7 @@ void GraphPerspective::start(tlp::PluginProgress *progress) {
   connect(_ui->actionNewProject, SIGNAL(triggered()), this, SLOT(newProject()));
   connect(_ui->actionPreferences,SIGNAL(triggered()),this,SLOT(openPreferences()));
   connect(_ui->searchButton,SIGNAL(clicked(bool)),this,SLOT(setSearchOutput(bool)));
-  connect(_ui->pythonButton,SIGNAL(clicked(bool)),this,SLOT(setPythonPanel(bool)));
   connect(_ui->workspace,SIGNAL(importGraphRequest()),this,SLOT(importGraph()));
-  connect(_ui->developButton, SIGNAL(clicked()), this, SLOT(setDevelopMode()));
   connect(_ui->workspaceButton, SIGNAL(clicked()), this, SLOT(setWorkspaceMode()));
   connect(_ui->action_Close_All, SIGNAL(triggered()), _ui->workspace, SLOT(closeAll()));
 
@@ -332,10 +351,6 @@ void GraphPerspective::start(tlp::PluginProgress *progress) {
   else
     _ui->actionShowDocumentation->setVisible(false);
 
-
-  tlp::PluginLister::instance()->addListener(this);
-  PythonInterpreter::getInstance()->setDefaultConsoleWidget(_ui->pythonPanel->consoleWidget());
-
   // Setting initial sizes for splitters
   _ui->mainSplitter->setSizes(QList<int>() << 350 << 850);
   _ui->mainSplitter->setStretchFactor(0,0);
@@ -355,12 +370,40 @@ void GraphPerspective::start(tlp::PluginProgress *progress) {
   _ui->workspace->setModel(_graphs);
   _ui->workspace->readProject(_project,rootIds,progress);
   _ui->searchPanel->setModel(_graphs);
-  _ui->pythonPanel->setModel(_graphs);
-  _ui->developFrame->setProject(_project);
-  _ui->pythonPanel->setPanelButton(_ui->pythonButton);
+
+#ifdef BUILD_PYTHON_COMPONENTS
+  connect(_ui->pythonButton,SIGNAL(clicked(bool)),this,SLOT(setPythonPanel(bool)));
+  connect(_ui->developButton, SIGNAL(clicked()), this, SLOT(setDevelopMode()));
+  _pythonPanel->setModel(_graphs);
+  _developFrame->setProject(_project);
+  _pythonPanel->setPanelButton(_ui->pythonButton);
+  tlp::PluginLister::instance()->addListener(this);
+  PythonInterpreter::getInstance()->setDefaultConsoleWidget(_pythonPanel->consoleWidget());
+
+  APIDataBase::getInstance()->loadApiFile(tlpStringToQString(tlp::TulipShareDir) + "/apiFiles/tulip.api");
+  APIDataBase::getInstance()->loadApiFile(tlpStringToQString(tlp::TulipShareDir) + "/apiFiles/Python-" + PythonInterpreter::getInstance()->getPythonVersionStr() + ".api");
+  APIDataBase::getInstance()->loadApiFile(tlpStringToQString(tlp::TulipShareDir) + "/apiFiles/tulipogl.api");
+  APIDataBase::getInstance()->loadApiFile(tlpStringToQString(tlp::TulipShareDir) + "/apiFiles/tulipgui.api");
+
+  PythonInterpreter::getInstance()->setOutputEnabled(false);
+
+  if (PythonInterpreter::getInstance()->runString("import PyQt4")) {
+    APIDataBase::getInstance()->loadApiFile(tlpStringToQString(tlp::TulipShareDir) + "/apiFiles/PyQt4.api");
+  }
+
+  PythonInterpreter::getInstance()->setOutputEnabled(true);
+#endif
 
   if (!_externalFile.isEmpty() && QFileInfo(_externalFile).exists()) {
+// There is a bug with Qt5 on windows that leads to incorrect viewport size for OpenGL views
+// when starting Tulip with a file to open. Seems something is not correctly initialized from
+// the Qt side when the views are created.
+// As a workaround, delay the opening of the file from one second.
+#if (QT_VERSION >= QT_VERSION_CHECK(5, 0, 0)) && defined(WIN32)
+    QTimer::singleShot(1000, this, SLOT(openExternalFile()));
+#else
     open(_externalFile);
+#endif
   }
 
   foreach(HeaderFrame *h, _ui->docksSplitter->findChildren<HeaderFrame *>()) {
@@ -376,22 +419,13 @@ void GraphPerspective::start(tlp::PluginProgress *progress) {
   // fill menu with recent documents
   buildRecentDocumentsMenu();
 
-  APIDataBase::getInstance()->loadApiFile(tlpStringToQString(tlp::TulipShareDir) + "/apiFiles/tulip.api");
-  APIDataBase::getInstance()->loadApiFile(tlpStringToQString(tlp::TulipShareDir) + "/apiFiles/Python-" + PythonInterpreter::getInstance()->getPythonVersionStr() + ".api");
-  APIDataBase::getInstance()->loadApiFile(tlpStringToQString(tlp::TulipShareDir) + "/apiFiles/tulipogl.api");
-  APIDataBase::getInstance()->loadApiFile(tlpStringToQString(tlp::TulipShareDir) + "/apiFiles/tulipgui.api");
-
-  PythonInterpreter::getInstance()->setOutputEnabled(false);
-
-  if (PythonInterpreter::getInstance()->runString("import PyQt4")) {
-    APIDataBase::getInstance()->loadApiFile(tlpStringToQString(tlp::TulipShareDir) + "/apiFiles/PyQt4.api");
-  }
-
-  PythonInterpreter::getInstance()->setOutputEnabled(true);
-
   showTrayMessage("GraphPerspective started");
 }
 
+void GraphPerspective::openExternalFile() {
+  open(_externalFile);
+}
+
 tlp::GraphHierarchiesModel* GraphPerspective::model() const {
   return _graphs;
 }
@@ -429,8 +463,15 @@ void GraphPerspective::exportGraph(Graph* g) {
   std::string filename = (exportFile = wizard.outputFile()).toUtf8().data();
   std::string exportPluginName = wizard.algorithm().toStdString();
 
-  if (filename.rfind(".gz") == (filename.length() - 3))
+  if (filename.rfind(".gz") == (filename.length() - 3)) {
+    if (exportPluginName == "TLPB Export") {
+      QMessageBox::critical(_mainWindow, QString("File error"),
+                            QString("TLPB Export does not support on the fly compression\n(induced by .gz extension) for " + exportFile));
+      return;
+    }
+
     os = tlp::getOgzstream(filename);
+  }
   else {
     if (exportPluginName == "TLPB Export")
       os = tlp::getOutputFileStream(filename,
@@ -452,7 +493,7 @@ void GraphPerspective::exportGraph(Graph* g) {
   delete os;
 
   if (!result) {
-    QMessageBox::critical(_mainWindow,trUtf8("Export error"),trUtf8("Failed to export to format") + wizard.algorithm());
+    QMessageBox::critical(_mainWindow,trUtf8("Export error"),trUtf8("Failed to export to format ") + wizard.algorithm());
   }
   else {
     addRecentDocument(wizard.outputFile());
@@ -515,21 +556,20 @@ void GraphPerspective::importGraph(const std::string& module,
   Graph* g;
 
   if (!module.empty()) {
-    PluginProgress* prg = progress(NoProgressOption);
+    PluginProgress* prg = progress(IsStoppable | IsCancellable);
     prg->setTitle(module);
     g = tlp::importGraph(module,data,prg);
 
     if (g == NULL) {
       QMessageBox::critical(_mainWindow,trUtf8("Import error"),
-                            QString("<i>") + module.c_str() + trUtf8("</i> failed to import data.<br/><br/><b>") + prg->getError().c_str() + "</b>");
+                            QString("<i>") + module.c_str() + trUtf8("</i> failed to import data.<br/><br/><b>") + tlp::tlpStringToQString(prg->getError()) + "</b>");
       delete prg;
       return;
     }
 
     delete prg;
-    std::string name;
 
-    if (!g->getAttribute<std::string>("name", name)) {
+    if (g->getName().empty()) {
       QString n = tlp::tlpStringToQString(module) + " - " + tlp::tlpStringToQString(data.toString());
       n.replace(QRegExp("[\\w]*::"),""); // remove words before "::"
       g->setName(tlp::QStringToTlpString(n));
@@ -699,7 +739,9 @@ void GraphPerspective::openProjectFile(const QString &path) {
     _project->openProjectFile(path,prg);
     QMap<QString,tlp::Graph*> rootIds = _graphs->readProject(_project,prg);
     _ui->workspace->readProject(_project,rootIds,prg);
-    _ui->developFrame->setProject(_project);
+#ifdef BUILD_PYTHON_COMPONENTS
+    _developFrame->setProject(_project);
+#endif
 
     for (QMap<QString,tlp::Graph*>::iterator it = rootIds.begin(); it != rootIds.end() ; ++it) {
       it.value()->setAttribute("file", std::string(path.toUtf8().data()));
