@@ -284,8 +284,8 @@ void SearchWidget::search() {
 
     if (isNumericComparison()) {
       DoubleProperty* doubleProp = new DoubleProperty(g);
-      doubleProp->setAllNodeValue(_ui->tableWidget->item(0, 0)->data(Qt::DisplayRole).toInt());
-      doubleProp->setAllEdgeValue(_ui->tableWidget->item(0, 0)->data(Qt::DisplayRole).toInt());
+      doubleProp->setAllNodeValue(_ui->tableWidget->item(0, 0)->data(Qt::DisplayRole).toDouble());
+      doubleProp->setAllEdgeValue(_ui->tableWidget->item(0, 0)->data(Qt::DisplayRole).toDouble());
       b = doubleProp;
     }
     else {
@@ -504,9 +504,7 @@ SearchOperator *SearchWidget::searchOperator() {
   if (isNumericComparison())
     op = NUMERIC_OPERATORS[_ui->operatorCombo->currentIndex()];
   else
-    op = _ui->caseSensitivityCheck->isChecked() ?
-         NOCASE_STRING_OPERATORS[_ui->operatorCombo->currentIndex()] :
-         STRING_OPERATORS[_ui->operatorCombo->currentIndex()];
+    op = _ui->caseSensitivityCheck->isChecked() ? STRING_OPERATORS[_ui->operatorCombo->currentIndex()] : NOCASE_STRING_OPERATORS[_ui->operatorCombo->currentIndex()];
 
   return op;
 }
