@@ -101,11 +101,10 @@ static const string AREA_PROPORTIONAL = "Area Proportional";
 /** This plugin enables to set the size of the graph's elements
  *  according to a metric.
  *
- *  \author David Auber University Bordeaux I France: Email:auber@tulip-software.org
  */
 class MetricSizeMapping:public SizeAlgorithm {
 public:
-  PLUGININFORMATION("Size Mapping","Auber","08/08/2003","","2.0", "Size")
+  PLUGININFORMATION("Size Mapping","Auber","08/08/2003","Maps the sizes of the graph elements onto the values of a given numeric property.","2.0", "Size")
   MetricSizeMapping(const PluginContext* context):SizeAlgorithm(context),
     entryMetric(NULL), entrySize(NULL), xaxis(true), yaxis(true), zaxis(true),
     mappingType(true), min(1), max(10), range(0), shift(0), nodeoredge(true) {
@@ -221,7 +220,7 @@ public:
 
         result->setNodeValue(itn, size);
 
-        if ((iter % 100 == 0) &&
+        if ((++iter % 500 == 0) &&
             (pluginProgress->progress(iter, maxIter)!=TLP_CONTINUE)) {
           delete itN;
 
@@ -229,8 +228,6 @@ public:
 
           return false;
         }
-
-        ++iter;
       }
 
       delete itN;
@@ -239,14 +236,12 @@ public:
       forEach(e, graph->getEdges()) {
         result->setEdgeValue(e, entrySize->getEdgeValue(e));
 
-        if ((iter % 100 == 0) &&
+        if ((++iter % 500 == 0) &&
             (pluginProgress->progress(iter, maxIter)!=TLP_CONTINUE)) {
           if (!mappingType) delete tmp;
 
           return false;
         }
-
-        ++iter;
       }
     }
     else {
@@ -263,7 +258,7 @@ public:
         size[1] = static_cast<float>(sizos);
         result->setEdgeValue(ite, size);
 
-        if ((iter % 100 == 0) &&
+        if ((++iter % 500 == 0) &&
             (pluginProgress->progress(iter, maxIter)!=TLP_CONTINUE)) {
           delete itE;
 
@@ -271,8 +266,6 @@ public:
 
           return pluginProgress->state()!=TLP_CANCEL;
         }
-
-        ++iter;
       }
 
       delete itE;
@@ -281,14 +274,12 @@ public:
       forEach(n, graph->getNodes()) {
         result->setNodeValue(n, entrySize->getNodeValue(n));
 
-        if ((iter % 100 == 0) &&
+        if ((++iter % 500 == 0) &&
             (pluginProgress->progress(iter, maxIter)!=TLP_CONTINUE)) {
           if (!mappingType) delete tmp;
 
           return pluginProgress->state()!=TLP_CANCEL;
         }
-
-        ++iter;
       }
     }
 
