@@ -35,6 +35,9 @@
 #include <QMessageBox>
 #include <QFile>
 #include <QApplication>
+#include <QImage>
+#include <QPainter>
+#include <QTimer>
 
 using namespace std;
 
@@ -56,9 +59,6 @@ static QGLFormat GlInit() {
 }
 
 GlComposite *readPolyFile(QString fileName) {
-
-  map<string,vector<vector<Coord> > > clearPolygons;
-
   GlComposite *composite=new GlComposite;
 
   QFile file(fileName);
@@ -123,7 +123,6 @@ GlComposite *readPolyFile(QString fileName) {
 
         if(!datas.empty()) {
 
-          clearPolygons[polygonName]=datas;
           composite->addGlEntity(new GlComplexPolygon(datas,Color(0,0,0,50),Color(0,0,0,255)),polygonName);
           datas.clear();
           currentVector.clear();
@@ -154,7 +153,6 @@ GlComposite *readPolyFile(QString fileName) {
     if(!currentVector.empty())
       datas.push_back(currentVector);
 
-    clearPolygons[polygonName]=datas;
     composite->addGlEntity(new GlComplexPolygon(datas,Color(0,0,0,50),Color(0,0,0,255)),polygonName);
   }
 
@@ -413,30 +411,44 @@ GoogleMapsGraphicsView::GoogleMapsGraphicsView(GoogleMapsView *googleMapsView, Q
   googleMaps->setProgressWidget(progressWidget);
   googleMaps->setAdresseSelectionDialog(addressSelectionDialog,addresseSelectionProxy);
 
-  connect(googleMaps, SIGNAL(currentZoomChanged()),
-          _googleMapsView, SLOT(currentZoomChanged()));
+  connect(googleMaps, SIGNAL(currentZoomChanged()), _googleMapsView, SLOT(currentZoomChanged()));
+  connect(googleMaps, SIGNAL(refreshMap()), this, SLOT(queueMapRefresh()));
+
+
+  _placeholderItem = new QGraphicsRectItem(0,0,1,1);
+  _placeholderItem->setBrush(Qt::transparent);
+  _placeholderItem->setPen(QPen(Qt::transparent));
+  scene()->addItem(_placeholderItem);
 
   QGraphicsProxyWidget *proxyGM = scene()->addWidget(googleMaps);
   proxyGM->setPos(0,0);
+  proxyGM->setParentItem(_placeholderItem);
+
+  glMainWidget = new GlMainWidget(0, googleMapsView);
+  glMainWidget->getScene()->setCalculator(new GlCPULODCalculator());
+  glMainWidget->getScene()->setBackgroundColor(Color(255,255,255,0));
+  glMainWidget->getScene()->setClearBufferAtDraw(false);
+
+  glWidgetItem = new GlMainWidgetGraphicsItem(glMainWidget, 512, 512);
+  glWidgetItem->setPos(0,0);
 
   while (!googleMaps->pageInit()) {
     QApplication::processEvents(QEventLoop::ExcludeUserInputEvents);
   }
 
-  glMainWidget = new GlMainWidget(0, googleMapsView);
-  glMainWidget->getScene()->setCalculator(new GlCPULODCalculator());
-  glMainWidget->getScene()->setBackgroundColor(Color(255,255,255,0));
-
-  glWidgetItem = new GlMainWidgetGraphicsItem(glMainWidget, 512, 512);
-  glWidgetItem->setPos(0,0);
-
   scene()->addItem(glWidgetItem);
+  glWidgetItem->setParentItem(_placeholderItem);
 
   // combo box to choose the map type
   viewTypeComboBox=new QComboBox;
   viewTypeComboBox->addItems(QStringList()<<"RoadMap"<<"RoadMap"<<"Satellite" << "Terrain" << "Hybrid" <<"Polygon" << "Globe");
   viewTypeComboBox->insertSeparator(1);
-  scene()->addWidget(viewTypeComboBox)->setPos(20,20);
+
+  QGraphicsProxyWidget *comboBoxProxy = scene()->addWidget(viewTypeComboBox);
+  comboBoxProxy->setParentItem(_placeholderItem);
+  comboBoxProxy->setPos(20,20);
+  comboBoxProxy->setZValue(1);
+
   connect(viewTypeComboBox,SIGNAL(currentIndexChanged(QString)),_googleMapsView,SLOT(viewTypeChanged(QString)));
 
   // 2 push buttons
@@ -445,13 +457,21 @@ GoogleMapsGraphicsView::GoogleMapsGraphicsView(GoogleMapsView *googleMapsView, Q
   zoomInButton->setFixedSize(29, 27);
   zoomInButton->setContentsMargins(0, 0, 0, 0);
   connect(zoomInButton, SIGNAL(pressed()), _googleMapsView, SLOT(zoomIn()));
-  scene()->addWidget(zoomInButton)->setPos(20, 50);
+  QGraphicsProxyWidget *buttonProxy = scene()->addWidget(zoomInButton);
+  buttonProxy->setParentItem(_placeholderItem);
+  buttonProxy->setPos(20, 50);
+
   // zoom -
   zoomOutButton = new QPushButton(QIcon(":/zoom-.png"), "");
   zoomOutButton->setFixedSize(29, 27);
   zoomOutButton->setContentsMargins(0, 0, 0, 0);
   connect(zoomOutButton, SIGNAL(pressed()), _googleMapsView, SLOT(zoomOut()));
-  scene()->addWidget(zoomOutButton)->setPos(20, 76);
+  buttonProxy = scene()->addWidget(zoomOutButton);
+  buttonProxy->setParentItem(_placeholderItem);
+  buttonProxy->setPos(20, 76);
+
+  setAcceptDrops(false);
+
 }
 
 GoogleMapsGraphicsView::~GoogleMapsGraphicsView() {
@@ -490,11 +510,19 @@ void GoogleMapsGraphicsView::cleanup() {
 
 void GoogleMapsGraphicsView::setGraph(Graph *graph) {
   if (this->graph != graph) {
+
+    GlGraphRenderingParameters rp;
+
+    if (this->graph) {
+      rp = glMainWidget->getScene()->getGlGraphComposite()->getRenderingParameters();
+    }
+
     cleanup();
     this->graph = graph;
 
     GlScene *scene=glMainWidget->getScene();
     GlGraphComposite *graphComposite=new GlGraphComposite(graph);
+    graphComposite->setRenderingParameters(rp);
     GlLayer *layer=scene->createLayer("Main");
     planisphereEntity = buildPlanisphereEntity(glMainWidget);
     layer->addGlEntity(planisphereEntity,"globeMap");
@@ -826,14 +854,16 @@ void GoogleMapsGraphicsView::resizeEvent(QResizeEvent *event) {
 }
 
 void GoogleMapsGraphicsView::paintEvent (QPaintEvent * event) {
-  pair<double, double> mapCenter = googleMaps->getCurrentMapCenter();
-  unsigned int mapZoom = googleMaps->getCurrentMapZoom();
 
   Observable::holdObservers();
 
   if (graph && !geocodingActive) {
 
-    if(googleMaps->isVisible()) {
+    if(googleMaps->isVisible() && (prevMapCenter != googleMaps->getCurrentMapCenter() || prevMapZoom != googleMaps->getCurrentMapZoom())) {
+
+      prevMapCenter = googleMaps->getCurrentMapCenter();
+      prevMapZoom = googleMaps->getCurrentMapZoom();
+
       float worldWidth = googleMaps->getWorldWidth();
       static const double maxLat = 85.05113f;
       Coord swPos = googleMaps->getPixelPosOnScreenForLatLng(-maxLat, 0.0);
@@ -841,14 +871,14 @@ void GoogleMapsGraphicsView::paintEvent (QPaintEvent * event) {
       Coord nePos = googleMaps->getPixelPosOnScreenForLatLng(maxLat, 0.0);
       nePos[1]=height() - nePos[1];
 
-      Coord mapCenterCoord = googleMaps->getPixelPosOnScreenForLatLng(mapCenter.first, mapCenter.second);
-      float westToMapCenterDist = ((mapCenter.second + 180.0) * worldWidth) / 360.0;
+      Coord mapCenterCoord = googleMaps->getPixelPosOnScreenForLatLng(prevMapCenter.first, prevMapCenter.second);
+      float westToMapCenterDist = ((prevMapCenter.second + 180.0) * worldWidth) / 360.0;
       swPos.setX(mapCenterCoord.getX() - westToMapCenterDist);
       nePos.setX(swPos.getX() + worldWidth);
 
-      currentMapCenter = mapCenter;
+      currentMapCenter = prevMapCenter;
       lastSceneRect = sceneRect();
-      currentMapZoom = mapZoom;
+      currentMapZoom = prevMapZoom;
 
       BoundingBox bb;
       Coord rightCoord = googleMaps->getPixelPosOnScreenForLatLng(180,180);
@@ -862,17 +892,24 @@ void GoogleMapsGraphicsView::paintEvent (QPaintEvent * event) {
         GlSceneZoomAndPan sceneZoomAndPan(glMainWidget->getScene(),bb,"Main",1);
         sceneZoomAndPan.zoomAndPanAnimationStep(1);
       }
-    }
 
-    glWidgetItem->setRedrawNeeded(true);
-    glMainWidget->getScene()->setBackgroundColor(Color(255,255,255,0));
-    glMainWidget->getScene()->setClearBufferAtDraw(false);
+      glWidgetItem->setRedrawNeeded(true);
+
+    }
   }
 
   Observable::unholdObservers();
 
   QGraphicsView::paintEvent(event);
+}
 
+void GoogleMapsGraphicsView::queueMapRefresh() {
+  QTimer::singleShot(500, this, SLOT(refreshMap()));
+}
+
+void GoogleMapsGraphicsView::refreshMap() {
+  glWidgetItem->setRedrawNeeded(true);
+  scene()->update();
 }
 
 void GoogleMapsGraphicsView::setMapTranslationBlocked(const bool translationBlocked) {
@@ -996,6 +1033,7 @@ void GoogleMapsGraphicsView::switchViewType() {
 
   case GoogleMapsView::Polygon: {
     enablePolygon=true;
+    glWidgetItem->setRedrawNeeded(true);
     break;
   }
 
@@ -1052,10 +1090,7 @@ void GoogleMapsGraphicsView::switchViewType() {
 
   planisphereEntity->setVisible(enablePlanisphere);
 
-  if(enableGoogleMap)
-    layer->setCamera(new Camera(glMainWidget->getScene()));
-  else
-    layer->setCamera(new Camera(glMainWidget->getScene()));
+  layer->setCamera(new Camera(glMainWidget->getScene()));
 
   if(viewType!=GoogleMapsView::Globe) {
     SizeProperty *viewSize = graph->getProperty<SizeProperty>("viewSize");
@@ -1076,7 +1111,7 @@ void GoogleMapsGraphicsView::switchViewType() {
       }*/
     }
 
-    if (edgeBendsLatLng.size() > 0) {
+    if (!edgeBendsLatLng.empty()) {
       edge e;
       forEach(e, graph->getEdges()) {
         vector<Coord> edgeBendsCoords;
