@@ -57,19 +57,19 @@ namespace tlp {
  *
  *  <b>LICENCE</b>
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU Lesser General Public License
+ * as published by the Free Software Foundation, either version 3
+ * of the License, or (at your option) any later version.
  */
 class GoogleMapsView : public View {
 
   Q_OBJECT
 
-  PLUGININFORMATION(ViewName::GoogleMapsViewName, "Antoine Lambert and Mathiaut Morgan", "06/2012",
+  PLUGININFORMATION(ViewName::GoogleMapsViewName, "Antoine Lambert and Morgan Mathiaut", "06/2012",
                     "<p>The Geographic view allows to visualize a geolocated Tulip graph on top of Google Maps.</p>"
-                    "<p>If geographic properties are attached to graph nodes (address or latitude/longitude), they are used used to layout the nodes on the map.</p>"
-                    "<p>An interactor for performing selection on graph elements is also bundled with the view.</p>", "2.0","View")
+                    "<p>If geographic properties are attached to graph nodes (address or latitude/longitude), they are used to layout the nodes on the map.</p>"
+                    "<p>An interactor for performing selection on graph elements is also bundled with the view.</p>", "2.1","View")
 
 public :
 
@@ -91,9 +91,7 @@ public :
 
   void setupUi();
 
-  QPixmap snapshot(const QSize&) const {
-    return QPixmap();
-  }
+  QPixmap snapshot(const QSize&) const;
 
   void setState(const DataSet &dataSet);
   DataSet state() const;
@@ -160,19 +158,20 @@ public slots :
   void zoomOut();
   void currentZoomChanged();
 
+  void openSnapshotDialog();
+
 protected slots:
 
   void fillContextMenu(QMenu *, const QPointF &);
 
 private :
 
-  void updatePoly();
+  void updatePoly(bool force=false);
 
   void loadStoredPolyInformations(const DataSet &dataset);
 
   void saveStoredPolyInformations(DataSet &dataset) const;
 
-  QGraphicsRectItem* _placeholderItem;
   GoogleMapsGraphicsView *googleMapsGraphicsView;
   GoogleMapsViewConfigWidget *googleMapsViewConfigWidget;
   GeolocalisationConfigWidget *geolocalisationConfigWidget;
