@@ -25,6 +25,7 @@
 #include <tulip/GlLabel.h>
 #include <tulip/GlRect.h>
 #include <tulip/GlTextureManager.h>
+#include <tulip/TlpQtTools.h>
 
 #include <QToolTip>
 #include <QHelpEvent>
@@ -70,7 +71,8 @@ HistogramView::HistogramView(const PluginContext *) :
   propertiesSelectionWidget(NULL), histoOptionsWidget(NULL), xAxisDetail(NULL), yAxisDetail(NULL), _histoGraph(NULL), emptyGraph(NULL),
   emptyGlGraphComposite(NULL), histogramsComposite(NULL), labelsComposite(NULL), axisComposite(NULL), smallMultiplesView(true), mainLayer(NULL), detailedHistogram(NULL),
   sceneRadiusBak(0), zoomFactorBak(0),
-  noDimsLabel(NULL), noDimsLabel2(NULL), emptyRect(NULL), emptyRect2(NULL), lastViewWindowWidth(0),
+  noDimsLabel(NULL), noDimsLabel1(NULL), noDimsLabel2(NULL), emptyRect(NULL),
+  emptyRect2(NULL), lastViewWindowWidth(0),
   lastViewWindowHeight(0), interactorsActivated(false), isConstruct(false), lastNbHistograms(0), dataLocation(NODE),needUpdateHistogram(false)  {
   ++histoViewInstancesCount;
 }
@@ -166,9 +168,11 @@ void HistogramView::cleanupGlScene() {
 
 void HistogramView::setState(const DataSet &dataSet) {
 
+  GlMainWidget *gl = getGlMainWidget();
+
   if(!isConstruct) {
     isConstruct=true;
-    getGlMainWidget()->installEventFilter(this);
+    gl->installEventFilter(this);
 
     setOverviewVisible(true);
 
@@ -179,8 +183,8 @@ void HistogramView::setState(const DataSet &dataSet) {
   }
 
   if (binTextureId == 0) {
-    getGlMainWidget()->makeCurrent();
-    binTextureId = getGlMainWidget()->bindTexture(QPixmap(":/histo_texture.png").transformed(QTransform().rotate(90)), GL_TEXTURE_2D);
+    gl->makeCurrent();
+    binTextureId = gl->bindTexture(QPixmap(":/histo_texture.png").transformed(QTransform().rotate(90)), GL_TEXTURE_2D);
     GlTextureManager::getInst().registerExternalTexture(BIN_RECT_TEXTURE, binTextureId);
   }
 
@@ -271,11 +275,31 @@ void HistogramView::setState(const DataSet &dataSet) {
       if (histogramParametersMap[selectedProperties[j]].get("y axis logscale", yAxisLogScale)) {
         histogramsMap[selectedProperties[j]]->setYAxisLogScale(yAxisLogScale);
       }
+
+      bool useCustomAxisScale = false;
+
+      if (histogramParametersMap[selectedProperties[j]].get("x axis custom scale", useCustomAxisScale)) {
+        histogramsMap[selectedProperties[j]]->setXAxisScaleDefined(useCustomAxisScale);
+      }
+
+      if (histogramParametersMap[selectedProperties[j]].get("y axis custom scale", useCustomAxisScale)) {
+        histogramsMap[selectedProperties[j]]->setYAxisScaleDefined(useCustomAxisScale);
+      }
+
+      std::pair<double, double> axisScale;
+
+      if (histogramParametersMap[selectedProperties[j]].get("x axis scale", axisScale)) {
+        histogramsMap[selectedProperties[j]]->setXAxisScale(axisScale);
+      }
+
+      if (histogramParametersMap[selectedProperties[j]].get("y axis scale", axisScale)) {
+        histogramsMap[selectedProperties[j]]->setYAxisScale(axisScale);
+      }
     }
 
   }
 
-  getGlMainWidget()->centerScene();
+  gl->centerScene();
   draw();
 
   registerTriggers();
@@ -304,12 +328,16 @@ DataSet HistogramView::state() const {
     histogramParameters.set("uniform quantification", histogramsMapTmp[selectedPropertiesTmp[i]]->uniformQuantificationHistogram());
     histogramParameters.set("x axis logscale", histogramsMapTmp[selectedPropertiesTmp[i]]->xAxisLogScaleSet());
     histogramParameters.set("y axis logscale", histogramsMapTmp[selectedPropertiesTmp[i]]->yAxisLogScaleSet());
+    histogramParameters.set("x axis custom scale", histogramsMapTmp[selectedPropertiesTmp[i]]->getXAxisScaleDefined());
+    histogramParameters.set("x axis scale", histogramsMapTmp[selectedPropertiesTmp[i]]->getXAxisScale());
+    histogramParameters.set("y axis custom scale", histogramsMapTmp[selectedPropertiesTmp[i]]->getYAxisScaleDefined());
+    histogramParameters.set("y axis scale", histogramsMapTmp[selectedPropertiesTmp[i]]->getYAxisScale());
     dataSet.set("histo"+ss.str(), histogramParameters);
   }
 
   dataSet.set("lastViewWindowWidth",  getGlMainWidget()->width());
   dataSet.set("lastViewWindowHeight",  getGlMainWidget()->height());
-  dataSet.set("backgroundColor", histoOptionsWidget->getBackgroundColor());
+  dataSet.set("backgroundColor", getGlMainWidget()->getScene()->getBackgroundColor());
   string histoDetailedNamed = "";
 
   if (detailedHistogram != NULL) {
@@ -333,7 +361,7 @@ bool HistogramView::eventFilter(QObject *object, QEvent *event) {
         sceneCoords.getY() > xAxisBB[0][1] && sceneCoords.getY() < xAxisBB[1][1]) {
       double val = xAxisDetail->getValueForAxisPoint(sceneCoords);
       string valStr(getStringFromNumber(val));
-      QToolTip::showText(he->globalPos(), QString(valStr.c_str()));
+      QToolTip::showText(he->globalPos(), tlp::tlpStringToQString(valStr));
     }
 
     return true;
@@ -411,6 +439,10 @@ void HistogramView::viewConfigurationChanged() {
     detailedHistogram->setCumulativeHistogram(histoOptionsWidget->cumulativeFrequenciesHisto());
     detailedHistogram->setUniformQuantification(histoOptionsWidget->uniformQuantification());
     detailedHistogram->setDisplayGraphEdges(histoOptionsWidget->showGraphEdges());
+    detailedHistogram->setXAxisScaleDefined(histoOptionsWidget->useCustomXAxisScale());
+    detailedHistogram->setXAxisScale(histoOptionsWidget->getXAxisScale());
+    detailedHistogram->setYAxisScaleDefined(histoOptionsWidget->useCustomYAxisScale());
+    detailedHistogram->setYAxisScale(histoOptionsWidget->getYAxisScale());
     detailedHistogram->setLayoutUpdateNeeded();
     detailedHistogram->update();
     histoOptionsWidget->setBinWidth(detailedHistogram->getHistogramBinsWidth());
@@ -419,13 +451,11 @@ void HistogramView::viewConfigurationChanged() {
   }
 
   updateHistograms(detailedHistogram);
-  getGlMainWidget()->centerScene();
+  drawOverview(true);
   draw();
 }
 
 void HistogramView::draw() {
-
-
   if (detailedHistogram != NULL) {
     needUpdateHistogram=true;
     detailedHistogram->update();
@@ -450,8 +480,9 @@ void HistogramView::draw() {
 
     removeEmptyViewLabel();
     addEmptyViewLabel();
-    getGlMainWidget()->getScene()->centerScene();
-    getGlMainWidget()->draw();
+    GlMainWidget *gl = getGlMainWidget();
+    gl->centerScene();
+    gl->draw();
     return;
   }
 
@@ -484,6 +515,7 @@ void HistogramView::refresh() {
 
 void HistogramView::graphChanged(Graph *) {
   setState(DataSet());
+  drawOverview();
 }
 
 void HistogramView::buildHistograms() {
@@ -684,6 +716,12 @@ void HistogramView::switchFromSmallMultiplesToDetailedView(Histogram *histogramT
   histoOptionsWidget->setXAxisLogScale(detailedHistogram->xAxisLogScaleSet());
   histoOptionsWidget->setCumulativeFrequenciesHistogram(detailedHistogram->cumulativeFrequenciesHistogram());
   histoOptionsWidget->setShowGraphEdges(detailedHistogram->displayGraphEdges());
+  histoOptionsWidget->useCustomXAxisScale(detailedHistogram->getXAxisScaleDefined());
+  histoOptionsWidget->setXAxisScale(detailedHistogram->getXAxisScale());
+  histoOptionsWidget->useCustomYAxisScale(detailedHistogram->getYAxisScaleDefined());
+  histoOptionsWidget->setYAxisScale(detailedHistogram->getYAxisScale());
+  histoOptionsWidget->setInitXAxisScale(detailedHistogram->getInitXAxisScale());
+  histoOptionsWidget->setInitYAxisScale(detailedHistogram->getInitYAxisScale());
 
   getGlMainWidget()->draw();
 }
@@ -707,24 +745,26 @@ void HistogramView::switchFromDetailedViewToSmallMultiples() {
 
   detailedHistogram = NULL;
   detailedHistogramPropertyName = "";
-
+  GlMainWidget *gl = getGlMainWidget();
   xAxisDetail = NULL;
   yAxisDetail = NULL;
   mainLayer->addGlEntity(histogramsComposite, "overviews composite");
   mainLayer->addGlEntity(labelsComposite, "labels composite");
-  getGlMainWidget()->getScene()->getGraphCamera().setSceneRadius(sceneRadiusBak);
-  getGlMainWidget()->getScene()->getGraphCamera().setZoomFactor(zoomFactorBak);
-  getGlMainWidget()->getScene()->getGraphCamera().setEyes(eyesBak);
-  getGlMainWidget()->getScene()->getGraphCamera().setCenter(centerBak);
-  getGlMainWidget()->getScene()->getGraphCamera().setUp(upBak);
+  Camera &cam = gl->getScene()->getGraphCamera();
+  cam.setSceneRadius(sceneRadiusBak);
+  cam.setZoomFactor(zoomFactorBak);
+  cam.setEyes(eyesBak);
+  cam.setCenter(centerBak);
+  cam.setUp(upBak);
 
   smallMultiplesView = true;
 
   toggleInteractors(false);
   propertiesSelectionWidget->setWidgetEnabled(true);
   histoOptionsWidget->setWidgetEnabled(false);
+  histoOptionsWidget->resetAxisScale();
 
-  getGlMainWidget()->draw();
+  gl->draw();
 }
 
 void HistogramView::updateDetailedHistogramAxis() {
@@ -758,12 +798,6 @@ BoundingBox HistogramView::getSmallMultiplesBoundingBox() const {
   return glBBSV.getBoundingBox();
 }
 
-/*void HistogramView::setInteractors(const std::list<Interactor *> &interactors) {
-  for(QList)
-  View::setInteractors(interactors);
-  toggleInteractors(false);
-}*/
-
 void HistogramView::registerTriggers() {
   foreach (tlp::Observable* obs, triggers()) {
     removeRedrawTrigger(obs);
