@@ -78,7 +78,6 @@ void ParallelCoordinatesDrawing::createAxis(GlMainWidget *glWidget,
 
   GlMainWidget::getFirstQGLWidget()->makeCurrent();
 
-  string propertyName;
   unsigned int pos = 0;
   vector<string> selectedProperties(graphProxy->getSelectedProperties());
   vector<string>::iterator it;
@@ -95,6 +94,9 @@ void ParallelCoordinatesDrawing::createAxis(GlMainWidget *glWidget,
   if (progressBar) {
     progressBar->setComment("Creating parallel axes ...");
     progressBar->progress(0, selectedProperties.size());
+    glWidget->getScene()->centerScene();
+    float glWidth = (float) glWidget->getScene()->getBoundingBox().width();
+    glWidget->getScene()->zoomFactor((glWidth - 50)/ glWidth);
     glWidget->draw();
     // needed to display progressBar
     QApplication::processEvents();
@@ -263,12 +265,12 @@ void ParallelCoordinatesDrawing::plotAllData(GlMainWidget *glWidget,
   computeResizeFactor();
 
   int currentStep = 0;
-  int maxStep = graphProxy->numberOfNodes();
-  int drawStep = maxStep / 20;
+  int maxStep = graphProxy->getDataCount();
+  int drawStep = maxStep / 100;
 
   if (progressBar) {
     progressBar->setComment("Updating parallel coordinates ...");
-    progressBar->progress(0, graphProxy->numberOfNodes());
+    progressBar->progress(0, maxStep);
     glWidget->draw();
     // needed to display progressBar
     QApplication::processEvents();
@@ -292,9 +294,8 @@ void ParallelCoordinatesDrawing::plotAllData(GlMainWidget *glWidget,
     }
 
     plotData(dataId, color);
-    ++currentStep;
 
-    if (progressBar && currentStep % drawStep == 0) {
+    if (progressBar && (++currentStep % drawStep == 0)) {
       progressBar->progress(currentStep, maxStep);
       glWidget->draw();
       // needed to display progressBar
