@@ -52,16 +52,14 @@ static const unsigned char states[4][3][4] = { { {0, 1, 3, 2},
 inline uPoint hilbertPoint(const unsigned int key, const unsigned char order) {
   //  cerr << "========" << endl;
   unsigned char state = 0;
-  unsigned char bits;
-  unsigned char co;
   uPoint point;
   point.fill(0);
 
   for (char i = order - 1; i >= 0; --i) {
     //read two bits;
-    bits = (key >> (i << 1))  & 3;
+    unsigned char bits = (key >> (i << 1))  & 3;
     //    unsigned char co = grState.graph[state].key[bits];
-    co = states[state][KEY][bits];
+    unsigned char co = states[state][KEY][bits];
     //    cerr << "state :" << (int) state << " bits" << bits << " co:" << (int)co;
     point[1] += (co & 1) << i;
     //    point[0] += ((co >> 1) & 1) << (i-1);
@@ -78,16 +76,14 @@ inline unsigned int hilbertKey(const uPoint &p, const unsigned char order) {
   //  cerr << "========" << endl;
   unsigned char state = 0;
   unsigned int key = 0;
-  unsigned char bits;
-  unsigned char co;
 
   for (char i = order - 1; i >= 0; --i) {
     //read two bits;
-    bits = (p[1] >> i)  & 1;
+    unsigned char bits = (p[1] >> i)  & 1;
     bits += ((p[0] >> i)  & 1) << 1;
     //    cerr << "p:" << p << " bits:" << bits << endl;
     //    unsigned char co = grState.graph[state].point[bits];
-    co = states[state][POINT][bits];
+    unsigned char co = states[state][POINT][bits];
     //    cerr << "state :" << (int) state << " bits" << bits << " co:" << (int)co;
     key += co << (i << 1);
     //    state = grState.graph[state].next[co];
