@@ -404,9 +404,8 @@ void StackWalkerMinGW::printCallStack(std::ostream &os, unsigned int maxDepth) {
       module_name = module_name_raw;
     }
 
-    std::string moduleNameStr(module_name);
-
 #ifdef HAVE_BFD
+    std::string moduleNameStr(module_name);
 
     if (bfdMap.find(moduleNameStr) == bfdMap.end()) {
       bfdMap[moduleNameStr] = new BfdWrapper(module_name);
@@ -447,10 +446,11 @@ void StackWalkerMinGW::printCallStack(std::ostream &os, unsigned int maxDepth) {
       func = "";
     }
 
-    std::pair<const char *, unsigned int> infos = std::make_pair("", 0);
-
 #ifdef HAVE_BFD
-    infos = bfdMap[moduleNameStr]->getFileAndLineForAddress(frame.AddrPC.Offset);
+    std::pair<const char *, unsigned int> infos =
+      bfdMap[moduleNameStr]->getFileAndLineForAddress(frame.AddrPC.Offset);
+#else
+    std::pair<const char *, unsigned int> infos = std::make_pair("", 0);
 #endif
 
     if (infos.first == NULL || infos.second == 0) {
@@ -479,8 +479,20 @@ void StackWalkerMSVC::printCallStack(std::ostream &os, unsigned int maxDepth) {
   HANDLE thread = GetCurrentThread();
 
   SymSetOptions(SYMOPT_DEFERRED_LOADS | SYMOPT_LOAD_LINES | SYMOPT_UNDNAME);
-  SymInitialize(process, NULL, TRUE);
 
+  if (!SymInitialize(process, NULL, TRUE)) {
+    std::cerr << "Failed to init symbol context" << std::endl;
+    return;
+  }
+
+  const int bufferSize = 2048;
+  char searchPaths[bufferSize];
+
+  if (!extraSymbolsSearchPaths.empty() && SymGetSearchPath(process, searchPaths, bufferSize)) {
+    std::string searchPathsStr(searchPaths);
+    searchPathsStr = extraSymbolsSearchPaths + ";" + searchPathsStr;
+    SymSetSearchPath(process, searchPathsStr.c_str());
+  }
 
   STACKFRAME        stack;
   ULONG               frame;
