@@ -39,7 +39,6 @@
 #include <tulip/PluginManager.h>
 #include <tulip/QuaZIPFacade.h>
 #include <tulip/TlpQtTools.h>
-#include <tulip/PythonVersionChecker.h>
 
 #include <CrashHandling.h>
 
@@ -103,8 +102,6 @@ void checkTulipRunning(const QString& perspName, const QString& fileToOpen) {
 
     if (ok && sendAgentMessage(n_agentPort,"SHOW_AGENT\tPROJECTS")) {
 
-      QMessageBox::warning(NULL, "Warning", "An instance of Tulip agent is already running,\ndisplaying it...");
-
       // if a file was passed as argument, forward it to the running instance
       if (!fileToOpen.isNull()) { // open the file passed as argument
         if (!perspName.isNull()) {
@@ -148,20 +145,6 @@ int main(int argc, char **argv) {
   QApplication::addLibraryPath(QApplication::applicationDirPath() + "/..");
 #endif
 
-#ifdef WIN32
-  // MS stated that SetDllDirectory only exists since WinXP SP1
-#if (_WIN32_WINNT >= 0x0502)
-
-  // Python on windows can be installed for current user only.
-  // In that case, the Python dll is not located in system path but in the Python home directory.
-  // So add the Python home directory in the Dll search paths in order to be able to load plugins depending on Python.
-  if (tlp::PythonVersionChecker::isPythonVersionMatching()) {
-    SetDllDirectory(tlp::PythonVersionChecker::getPythonHome().toStdString().c_str());
-  }
-
-#endif
-#endif
-
   // Parse arguments
   QRegExp perspectiveRegexp("^\\-\\-perspective=(.*)");
   QString perspName;
@@ -190,6 +173,12 @@ int main(int argc, char **argv) {
   delete dispatcher;
   delete splashScreen;
 
+#ifdef _MSC_VER
+  // Add path to Tulip pdb files generated by Visual Studio (for configurations Debug and RelWithDebInfo)
+  // It allows to get a detailed stack trace when Tulip crashes.
+  setExtraSymbolsSearchPaths(tlp::TulipShareDir + "pdb");
+#endif
+
   // Main window
   TulipMainWindow *mainWindow = TulipMainWindow::instance();
   mainWindow->pluginsCenter()->reportPluginErrors(errorReport->errors());
